package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.38.2 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.38.2) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````(`*``!````Q!@!`#0```!TD0````0`!30`(``)
M`"@`'``;``$``'!,B```3(@!`$R(`0`(````"`````0````$````!@```#0`
M```T``$`-``!`"`!```@`0``!`````0````#````5`$``%0!`0!4`0$`&0``
M`!D````$`````0````$````````````!`````0!8B```6(@```4`````$```
M`0```,R-``#,G0$`S)T!`$P"``!T`@``!@`````0```"````[(T``.R=`0#L
MG0$`"`$```@!```&````!`````0```!P`0``<`$!`'`!`0!$````1`````0`
M```$````4>5T9```````````````````````````!@```!````!2Y71DS(T`
M`,R=`0#,G0$`-`(``#0"```$`````0```"]L:6(O;&0M;&EN=7@M87)M:&8N
M<V\N,P`````$````%`````,```!'3E4`T#E`Y!0V3Z#)WJ42^Q.WM].W=1,$
M````$`````$```!'3E4```````,````"`````````&$````%````(`````H`
M``"(`A```$01``````!6`'`8@@``,`@@$!$"`!`"`"@````H```02`(@"@`*
M`(2$0JA```%@80"$"#Y"-),``0`()%B`!(E@#),X`$)*0$0`0``!`$()`$"`
MC,"$```0D!"#"0`(`1"`@$!``@F`#$"(`D$((L`@!`D`D``D#I-&0`4`````
M````!@````<````(``````````````````````````D````+````#0````\`
M```0````$0```!,````6`````````````````````````!@````;````'```
M`!\````@````(0```"(`````````(P```"4````I`````````"H`````````
M`````"L````M````+@```"\````Q````,@```#,````U````-@``````````
M````-P```#D````Z`````````#L````\````/@```$````!#````````````
M`````````````$0`````````````````````````````````````````````
M`$4```!&`````````$@`````````2@```$P```!/````````````````````
M`````%````!4````50```%8`````````6```````````````6P``````````
M````70```%\```!@````80```&0```!?EI,<HUKOD,..A_\-.I<+TE$$A(%T
M@@UZ\$IKF4_#FW94/)3-/PRO]R/.((D'<--F62_EU634?"Y./?9FK\QFV_<`
M7@:DA_\!KS3HSDJN_\[>1RWAIP(*XT?&`<8.X#T^?I9\[3^0`FL:GE#%B060
M89CO$@$C^:1"^M>'G;N3'$)%U>Q0[A'CAOF<@7WM$0^[E9,<04V=?*QP#J^G
MW:-K6>^7>3GRBQP$,J6%HP+V&0TMO$7[H6Q@R#E`'S-BV^T_GD)$Z?O#P@J*
M$%?MWI,<K4OCP-EQ6!PKT.$B&I_6O2T.L7-8.T`?P^4_+)@BU&BZXY)\(?_D
M#F]Z:?K?A2!/Q;F<0%`;?5\QN((-OMI7&[,!BV^\T$M]=V_C<"1U@@UJ"4/6
MGR+'J"%B9`=^J9R;8M#Z@NPL]HMK?YI\A_"6?!6,)<SN"U'Y\]O3'<#D&9>0
M=8(-0V9+$#RM.0T7ZEKQIIN3'*/@^TE7DEI2_=+O#V[%WQ]\D!#I+=_^2"[%
MF[;)U;)Q`````````````````````!```````````````"````!C````````
M```````6`````0``````````````(````"P``````````````"````#Q`0``
M```````````2````D@(`````````````$@```+(!`````````````!(```#.
M`P```*`!```````@`!<`70$`````````````$@```","`````````````!(`
M``!-`0``(!0!```````2````;00``/`I`0!4````$@`-`%,#```8H`$`````
M`!``&``4`@`````````````2````_P$`````````````$@```/X#```4H`$`
M!````!$`%P":`@`````````````2````?@0``.0R`0",`@``$@`-`-$!````
M`````````!(```"H`P``L",!`$`!```2``T`*@(`````````````$@```!P"
M`````````````!(```"0`P``0*`!```````0`!@`<P,`````````````$@``
M`+0#``#D+`$```8``!(`#0#H`P``8"`!`.@````2``T`FP,``(`C`0`P````
M$@`-`$X"`````````````!(```"Z`@`````````````2````-`$`````````
M````$@```"($``"D1`$`5`$``!(`#0#G`@``&*`!``0````A`!@`^`$`````
M````````$@```*D"`````````````!(```#!`P``4$,!`%0!```2``T`.0(`
M````````````$@```(@#```8H`$``````!``%P#C`0`````````````2````
M=@```#`6`0``````$@```&`"`````````````!(```":`0`````````````2
M````E0$`````````````$@```(("`````````````!(```#H`@``&*`!``0`
M```A`!@`#00``$"@`0``````$``8`'0"```HH`$`!````!$`&``_`0``````
M```````2````&P$`````````````$@```*$!`````````````!(```!-!```
M_"L!`.@````2``T`R`(`````````````$@```-(#``#$&`$``````!(`#0"6
M```````````````2````H@``````````````$@```,8````@H`$``0```!$`
M&``&`@`````````````2````V0,``"1&`0`$````$0`/`"P$```8H`$`````
M`!``&`!6`@`````````````2````N0$`````````````$@```$8`````````
M`````!(```#3```````````````2````.`0``"@@`0`X````$@`-`.0`````
M`````````!(````(!```0*`!```````0`!@`0`0``$PA`0`T`@``$@`-`/`"
M`````````````!(```"W```````````````2````Y@(``!B@`0`$````$0`8
M``T!`````````````!(````-`@`````````````2````CP,``$"@`0``````
M$``8`%\$``!T*0$`?````!(`#0"'```````````````2````B@(`````````
M````$@```$<"`````````````!(```#,`P```*`!```````0`!<`9@(`````
M````````$@````(#``#4G0$`!````!$`%`!A`P``V"L!`"0````2``T`>P$`
M````````````$@```&@!`````````````!(```#>`0``D!8!`#0"```2``T`
MZ0``````````````$@```'4$``#(0@$`B````!(`#0"_`@`````````````2
M````A@$``-B=`0`3````$0`4`,$!`````````````!(```![`@``````````
M```2````,P(`````````````$@```'0!`````````````!(```#9`@``````
M```````2````0`(`````````````$@```!4$``#P)`$`A`0``!(`#0#N````
M```````````2````X`(`````````````$@```'P#``!P-0$`!`$``!(`#0!4
M```````````````2````*P$`````````````$@```$(#``!((0$`!````!(`
M#0#Z````N!4!```````2`````%]?9VUO;E]S=&%R=%]?`%])5$U?9&5R96=I
M<W1E<E1-0VQO;F5486)L90!?251-7W)E9VES=&5R5$U#;&]N951A8FQE`%!E
M<FQ?<WES7W1E<FT`4&5R;%]S>7-?:6YI=#,`4$Q?8W5R<F5N=%]C;VYT97AT
M`%!E<FQ?871F;W)K7VQO8VL`<&5R;%]C;VYS=')U8W0`4&5R;%]G971?<W8`
M4&5R;%]C<F]A:U]N;V-O;G1E>'0`4&5R;%]S=E]S971P=FX`4$Q?9&]?=6YD
M=6UP`%!E<FQ?;F5W6%-?9FQA9W,`<&5R;%]F<F5E`%!E<FQ?;6=?<V5T`%!E
M<FQ?871F;W)K7W5N;&]C:P!097)L7W-V7W-E='!V`%!E<FQ?9W9?9F5T8VAP
M=@!P97)L7W)U;@!097)L7VYE=UA3`'!E<FQ?9&5S=')U8W0`8F]O=%]$>6YA
M3&]A9&5R`'!E<FQ?<&%R<V4`4&5R;%]S869E<WES;6%L;&]C`'!E<FQ?86QL
M;V,`4$Q?;65M;W)Y7W=R87``<F5A9`!S=')C:'(`7U]L<W1A=#8T7W1I;64V
M-`!G971P:60`;65M;6]V90!?7W-T870V-%]T:6UE-C0`7U]L:6)C7W-T87)T
M7VUA:6X`7U]F<')I;G1F7V-H:P!S=')C;7``;W!E;C8T`'5N;&EN:P!S=')T
M;VL`;65M<V5T`'-T<FYC;7``9V5T=6ED`&UE;6-H<@!C;&]S961I<@!R;61I
M<@!S=')L96X`<W1R9'5P`&UE;6-M<`!R96%L;&]C`')E861D:7(V-`!A8F]R
M=`!?7W-P<FEN=&9?8VAK`'-T9&5R<@!M96UC<'D`<W1R<F-H<@!O<&5N9&ER
M`&QS965K-C0`7U]V9G!R:6YT9E]C:&L`7U]E<G)N;U]L;V-A=&EO;@!E>&ET
M`')E861L:6YK`%]?<W1A8VM?8VAK7V9A:6P`86-C97-S`&UK9&ER`%]?96YV
M:7)O;@!?7W)E9VES=&5R7V%T9F]R:P!?7W-T86-K7V-H:U]G=6%R9`!L:6)P
M97)L+G-O+C4N,S@`;&EB8RYS;RXV`&QD+6QI;G5X+6%R;6AF+G-O+C,`<&%R
M7V-U<G)E;G1?97AE8P!?7V)S<U]S=&%R=%]?`&=E=%]U<V5R;F%M95]F<F]M
M7V=E='!W=6ED`'!A<E]C;&5A;G5P`%]E9&%T80!?7V)S<U]E;F1?7P!P87)?
M8F%S96YA;64`<&%R7V1I<FYA;64`<&%R7VUK=&UP9&ER`'-H85]U<&1A=&4`
M7U]D871A7W-T87)T`%])3U]S=&1I;E]U<V5D`'!A<E]C=7)R96YT7V5X96-?
M<')O8P!M>5]P87)?<&P`7V5N9`!?7V5N9%]?`'!A<E]I;FET7V5N=@!S:&%?
M9FEN86P`7U]B<W-?<W1A<G0`>'-?:6YI=`!P87)?9FEN9'!R;V<`<&%R7W-E
M='5P7VQI8G!A=&@`<&%R7V5N=E]C;&5A;@!P87)?9&EE`'-H85]I;FET`%A3
M7TEN=&5R;F%L<U]005)?0D]/5`!'3$E"0U\R+C0`1TQ)0D-?,BXS-``````!
M``$``0`!``,``P`#``$``0`#``$``0`!``,``P`!``,``0`"``$``P`#``$`
M`P`!``$``0`#``,``0`!``,``P`#``$``P`!``,``0`#``,``P`#``,``0`#
M``$``0`"``$``P`!``$``0`!``,``0`!``,``P`!``$``0`!``$``0`#``$`
M`P`!``,``0`!``$``P`#``$``P`$``$``0`!``$``P`!``,``0`"``,``P`#
M``,``P`!``$``P`!``$``0`!``$````!``$`+@,``!`````@````%&EI#0``
M!`"4!`````````$``@`D`P``$``````````4:6D-```#`)0$```0````M)&6
M!@```@">!````````/2?`0`3`@``^)\!`!4#``#4G0$`%$\``-B=`0`45P``
M&*`!`!1%```@H`$`%#<``"B@`0`4+@```)\!`!98```$GP$`%A,```B?`0`6
M!0``#)\!`!88```0GP$`%BH``!2?`0`6%@``&)\!`!8\```<GP$`%E0``""?
M`0`660``))\!`!8+```HGP$`%EH``"R?`0`62@``,)\!`!9,```TGP$`%D``
M`#B?`0`670``/)\!`!8S``!`GP$`%D,``$2?`0`6#P``2)\!`!8<``!,GP$`
M%B\``%"?`0`61@``5)\!`!96``!8GP$`%E$``%R?`0`6!@``8)\!`!92``!D
MGP$`%DL``&B?`0`6(0``;)\!`!9;``!PGP$`%A$``'2?`0`6,```>)\!`!8#
M``!\GP$`%@<``("?`0`6'0``A)\!`!8D``"(GP$`%F(``(R?`0`6*0``D)\!
M`!8U``"4GP$`%B(``)B?`0`63@``G)\!`!8V``"@GP$`%AX``*2?`0`68```
MJ)\!`!9'``"LGP$`%F4``+"?`0`6/0``M)\!`!9?``"XGP$`%@D``+R?`0`6
M)@``P)\!`!8^``#$GP$`%@H``,B?`0`67```S)\!`!8X``#0GP$`%C$``-2?
M`0`6)P``V)\!`!8K``#<GP$`%CL``."?`0`61```Y)\!`!9C``#HGP$`%@X`
M`.R?`0`6*```\)\!`!85```(0"WI6@$`ZPB`O>@$X"WE!."?Y0[@C^`(\+[E
M1(L```#&C^((RHSB1/N\Y0#&C^((RHSB//N\Y0#&C^((RHSB-/N\Y0#&C^((
MRHSB+/N\Y0#&C^((RHSB)/N\Y0#&C^((RHSB'/N\Y0#&C^((RHSB%/N\Y0#&
MC^((RHSB#/N\Y0#&C^((RHSB!/N\Y0#&C^((RHSB_/J\Y0#&C^((RHSB]/J\
MY0#&C^((RHSB[/J\Y0#&C^((RHSBY/J\Y0#&C^((RHSBW/J\Y0#&C^((RHSB
MU/J\Y0#&C^((RHSBS/J\Y0#&C^((RHSBQ/J\Y0#&C^((RHSBO/J\Y0#&C^((
MRHSBM/J\Y0#&C^((RHSBK/J\Y0#&C^((RHSBI/J\Y0#&C^((RHSBG/J\Y0#&
MC^((RHSBE/J\Y0#&C^((RHSBC/J\Y0#&C^((RHSBA/J\Y0#&C^((RHSB?/J\
MY0#&C^((RHSB=/J\Y0#&C^((RHSB;/J\Y0#&C^((RHSB9/J\Y0#&C^((RHSB
M7/J\Y0#&C^((RHSB5/J\Y0#&C^((RHSB3/J\Y0#&C^((RHSB1/J\Y0#&C^((
MRHSB//J\Y0#&C^((RHSB-/J\Y0#&C^((RHSB+/J\Y0#&C^((RHSB)/J\Y0#&
MC^((RHSB'/J\Y0#&C^((RHSB%/J\Y0#&C^((RHSB#/J\Y0#&C^((RHSB!/J\
MY0#&C^((RHSB_/F\Y0#&C^((RHSB]/F\Y0#&C^((RHSB[/F\Y0#&C^((RHSB
MY/F\Y0#&C^((RHSBW/F\Y0#&C^((RHSBU/F\Y0#&C^((RHSBS/F\Y0#&C^((
MRHSBQ/F\Y0#&C^((RHSBO/F\Y0#&C^((RHSBM/F\Y0#&C^((RHSBK/F\Y0#&
MC^((RHSBI/F\Y0#&C^((RHSBG/F\Y0#&C^((RHSBE/F\Y0#&C^((RHSBC/F\
MY0#&C^((RHSBA/F\Y0#&C^((RHSB?/F\Y0#&C^((RHSB=/F\Y0#&C^((RHSB
M;/F\Y0#&C^((RHSB9/F\Y0'*H.-P0"WI#,!-X-`/C.4@T$WBW#&?Y10`C>40
M$(WE#""-Y1`0C>(,((WB%`"-X@`PD^4<,(WE`#"@XY[__^NT(9_EM`&?Y0(0
MH.')"P#KK#&?Y0!`T^4``%3C0@``"J`QG^7!"P#K%%"=Y0,PG^<#()#G!`"%
MX@<!<./6,]+E`U"%X@,P@^/6,\+E40``B@`!H.%J___K;"&?Y6Q!G^40$)WE
M#,"2Y10@G>4`X)'E7&&?Y0$`4N,`,*#A!`"$Y5`!G^4$8(/E`."#Y0C`@^4,
M`(/E0@``V@0`0>("`8#@#,"#X@3@L>4!`%#A!."LY?O__QH#$(+B``"@XP``
MC>4%(*#A`0&#YPP1G^4,`)3EC?__ZP``4.,?```*#`"4Y3C__^L8$(WB`%"@
MX>P`G^5]``#K``!0XQH```H,`)3E'O__ZWK__^NH,)_E`""3Y1PPG>4"(#/@
M`#"@XR0``!H%`*#A(-"-XG"`O>@N___KF""?Y0``4.,,`(+E&@``"@C__^N8
M,)_E>`L`ZP,PG^<#,)#GOD;#Y;#__^H,`)3EBO__Z]S__^H(`)3E``!0XP$`
M``I)!P#KW___ZF0`G^48$(WB6```ZP``4.,(`(3EV?__"O;__^I,$)_E3`"?
MY43__^L$$*#CPO__Z@$`H.,K___K]_[_Z]2=`0"X%0$`,!8!`""@`0#PB```
M"*`!`#"@`0#820$`W$D!`*0?`0!\1P$`T(<``!A'`0#8G0$`&$D!``"PH.,`
MX*#C!!"=Y`T@H.$$("WE!``MY1R@G^48,(_B`Z"*X``PH.,$,"WE#`"?Y0``
MFN>P_O_K7?__Z_2%```(`0``%#"?Y10@G^4#,(_@`B"3YP``4N,>_R\!_?[_
MZMR%```$`0``&`"?Y1@PG^4``%/A'O\O`1`PG^4``%/C'O\O`1/_+^$8H`$`
M&*`!```````D`)_E)#"?Y0`P0^"C'Z#A0Q&!X,$0L.$>_R\!$#"?Y0``4^,>
M_R\!$_\OX1B@`0`8H`$``````!!`+>D80)_E`##4Y0``4^,0@+T8X/__ZP$P
MH.,`,,3E$("]Z"R@`0#F___J`<J@X_!'+>D,P$W@X`^,Y0"`4.(J```*M#"?
MY0"0D^4``%GC*```"@!0V.4!<*#A``!5XST`51,!4*`3`%"@`Q$``!H`0)GE
M``!4XPP```H)8*#A!2"@X0@0H.$$`*#A$O__ZP``4.,"```:!3#4YST`4^,+
M```*!$"VY0``5./S__\:!`"@X?"'O>@(4*#A`3#UY0``4^,]`%,3^___&@A0
M1>#F___J"6!&X`%0A>)&8:#A!4"$X`0`H.$`8(?E\(>]Z`A`H.'M___J"4"@
MX>O__^H8H`$``<J@XQ!`+>D,P$W@@`^,Y70PG^5XT$WB#1"@X0!`H.$`,)/E
M=#"-Y0`PH./7_O_K``!0XP``H!,$```:$#"=Y0\Z`^(*"E/C`0E3$P<```HT
M,)_E`""3Y70PG>4"(#/@`#"@XP<``!IXT(WB$("]Z`(0H.,$`*#AOO[_ZQ`/
M;^&@`J#A\?__ZE'^_^O4G0$``<J@X_!`+>D,P$W@:`^,Y4`QG^6$T$WB`&!0
MX@`PD^5\,(WE`#"@XP(```H`,-;E``!3XP<``!H8,9_E`""3Y7PPG>4"(#/@
M`#"@XT```!J$T(WB\("]Z%?^_^L`0%#B]/__"@0`H.&M_O_K``!0XRD```H3
M,-#E$U"`XBX`4^,"```:`3#5Y0``4^/T__\*$S#0Y2X`4^,D```*!@"@X5W^
M_^L`<*#A!0"@X5K^_^L``(?@`@"`XD7^_^N8,)_E`"#@XP$0H.,$4(WE`&"-
MY0!PH.%?_O_K"!"-X@<`H.'J_?_K`0!PXP<`H.$#```*&#"=Y0\Z`^(!"5/C
M$@``"A7^_^L'`*#A]?W_ZP0`H.&#_O_K``!0X]7__QH$`*#ACO[_ZP8`H.'V
M_?_KP?__Z@$PU>4N`%/CU___&@(PU>4``%/CQO__"M/__^JK___KZ___ZOK]
M_^O4G0$`N$8!``'*H./P1RWI#,!-X-@/C.4`,-'E`4"@X>`AG^4]`%/C`4"!
M`@C03>(`4*#A!`"@X0`@DN4$((WE`""@XQ[^_^L-$*#A`&"@X04`H.$Y___K
M`)!0XCP```H7_O_K``!6X3,``)H`<)WEE(&?Y0=QH.$`,-7E``!3XST`4Q,!
M,*`3`#"@`P4```H%,*#A`2#SY0``4N,]`%(3^___&@4P0^`"`(;B`P"`X`!@
MF.7P_?_K``!0XP<`AN<5```*`""8Y04`H.$!,-#D!Q"2YST`4^,``%,3`##!
MY08```H!(('B`3#0Y`(0H.$]`%/C``!3$P$PPN3Y__\:`2"@X3TPH.,`,,'E
M`3#4Y```4^,!,.+E^___&N0PG^4`()/E!#"=Y0(@,^``,*#C,P``&@C0C>+P
MA[WH`9!)X@$PU.0``%/C`3#IY?O__QKQ___JL("?Y0!PF.4`,)?E``!3XR,`
M``H',*#A!""SY0D0H.$``%+C`9")XOK__QH#$('B`1&@X8`PG^4`()/E``!2
MXP\``!H!(*#C`0"@X0`@@^6T_?_K`*!0XMK__PH'$*#A"7&@X0<@H.%O_?_K
M`*"(Y0"0C>4!D(GB`#"@XPDQBN>G___J!P"@X8O]_^L``%#C`*"@X0``B.7*
M__\*"7&@X?+__^H#D*#A"!"@X^#__^IX_?_KU)T!`!B@`0`PH`$``<J@XW!`
M+>D,P$W@``",Y1@`#.4!VDWB"-!-XMPPG^4`8*#A`0J-X@0`@.(`,)/E`#"`
MY0`PH./$()_EQ`"?Y0%0H.$$$(WB=/W_ZP!`4.('``#:`2!$X@@PC>(",(/@
M!#!3Y0``4^,4```:``!2XQ$``!J0,)_EO`D`ZP4@H.$#,)_G!A"@X0,`D.=@
M_?_K`1J-XF0PG^4$$('B`""3Y0`PD>4"(#/@`#"@XQ(``!H!VHWB"-"-XG"`
MO>@"0*#A!""@X2\0H.,$`(WBI_W_ZP``4./F__\*,!"?Y:,)`.L$,*#A`1"?
MYP0@C>(!`)#G!A"@X;+]_^OD___J-?W_Z]2=`0#_#P``P$8!`-R```!X@```
M`<J@XS!`+>D,P$W@Z`^,Y4Q0G^4,T$WBCPD`ZP50G^<`0*#A/#"?Y3P@G^4\
M$)_E!0"0YVW]_^LT`)_E-#"?Y0#`H.,``)_G+""?Y2P0G^4``)3G"!"-Z'S]
M_^L,T(WB,("]Z"R```!XAP$`(!0!`-!&`0`$@```U$D!`.0R`0#L1@$`$$`M
MZ7,)`.L80)_E&#"?Y1@@G^4$0)_G%!"?Y00`D.<00+WH4/W_ZK!_``!XAP$`
M(!0!`-!&`0`!RJ#C,$`MZ0S`3>```(SE`<I,X@``C.4H``SE`MI-XAS03>*L
M,)_E`AJ-XA00@>(`,)/E`#"!Y0`PH.,A_?_KE,"?Y90PG^64()_E`1"@XP$0
MC>@,`(WB+_W_ZP$:C>(!*J#C$!"!X@P`C>+W_/_K`$!0X@!0H+,)``"Z`0"$
MX@3]_^L`4%#B!0``"@$:C>($(*#A$!"!XL7\_^L`,*#C!##%YP(:C>(H,)_E
M%!"!X@`@D^4`,)'E`B`SX``PH.,#```:!0"@X0+:C>(<T(WB,("]Z,O\_^O4
MG0$`$$<!``1'`0`!$```Q/__Z@'*H./P1RWI#,!-X```C.6H``SE0MU-X@C0
M3>+T,9_E0LV-X@!0H.$!8*#AZ`&?Y1`0C>($P(SB`#"3Y0`PC.4`,*#C"?[_
MZR\0H.,`0*#A!0"@X>S\_^L``%#C#@``"K@!G^4%$*#ALO[_ZP4`H.%"'8WB
MG#&?Y000@>(`()/E`#"1Y0(@,^``,*#C8```&D+=C>((T(WB\(>]Z`8`H.&:
M_/_K>!&?Y0?]_^L`D%#BZO__"@`PV>5H@9_E:'&?Y0``4^-889_E.@``"@``
M5.,$```*"1"@X00`H.%G_/_K``!0XRL```H)`*#AP/S_ZP$@0.("((G@`@!9
MX0`PH.$`H*#A`#"),``0H#,!`(DR`P``.@@``.H#`%#A`!##Y0(```H!('/E
M+P!2X_G__PH)`*#AKOS_ZP"@H.$%`*#AJ_S_ZPH`@.`!`(#B`0I0X\+__RH'
M,*#A`2J@XP$0H..$`(WB"%"-Y02`C>4`D(WEKOS_ZQ`0C>*$`(WB.?S_ZP``
M4.,#```:(#"=Y0\Z`^(""5/C$P``"@80H.$``*#CR?S_ZP"04.*L__\*`##9
MY0``4^/$__\:``!4XP(```H`,-3E+@!3XP(```I<D)_E`:"@X]C__^H!,-3E
M``!3X^S__PKX___J`1"@XX0`C>*R_/_K``!0X^;__QH<`)_EA!"-XDO^_^N$
M`(WB/_S_ZY;__^I`_/_KU)T!`!A'`0`D1P$`-$<!`$!'`0`X1P$`%$<!``'*
MH.,00"WI#,!-X/@/C.4O$*#C`$"@X:?\_^L``%#C`4"`$@0`H.$00+WH*OS_
MZ@'*H.-P0"WI#,!-X```C.48``SE`=I-X@C03>(!&HWB$#&?Y0!04.($$('B
M`#"3Y0`P@>4`,*#C+@``"@`PU>4``%/C*P``"E#\_^L!((#B`0I2XP!`H.$S
M``"*!&"-X@40H.$&`*#A_?O_ZP$P1.(#,(;@`P!6X0D``"H$`(;@!2"-X@`0
MH.,"``#J`@!0X0`0P.4"```*`3!PY2\`4^/Y__\*+Q"@XP8`H.%V_/_K``!0
MXP\```H&`%#A`#"@@P`PP(4&`*#A]_O_ZP$:C>)@,)_E!!"!X@`@D^4`,)'E
M`B`SX``PH.,1```:`=J-X@C0C>)P@+WH`1J-XC0PG^4$$('B`""3Y0`PD>4"
M(#/@`#"@XP8``!H<`)_E`=J-X@C0C>)P0+WHW_O_Z@``H./E___JW_O_Z]2=
M`0`41P$``<J@XS!`+>D,P$W@Z`^,Y2`TG^4,T$WB'$2?Y1Q4G^4`,)/E!#"-
MY0`PH.,-$*#A!`"@X23]_^L``%#C#```"@`0G>4`()7E`3&"X`0`D^4``%#C
M`0&"Y_/__PH$,(/B!""3Y0``4N,$((/D^___&NW__^K(0Y_EP%.?Y0T0H.$$
M`*#A$/W_ZP``4.,,```*`!"=Y0`@E>4!,8+@!`"3Y0``4.,!`8+G\___"@0P
M@^($()/E``!2XP0@@^3[__\:[?__ZGQ#G^5P4Y_E#1"@X00`H.'\_/_K``!0
MXPP```H`$)WE`""5Y0$Q@N`$`)/E``!0XP$!@N?S__\*!#"#X@0@D^4``%+C
M!""#Y/O__QKM___J,$.?Y2!3G^4-$*#A!`"@X>C\_^L``%#C#```"@`0G>4`
M()7E`3&"X`0`D^4``%#C`0&"Y_/__PH$,(/B!""3Y0``4N,$((/D^___&NW_
M_^KD0I_ET%*?Y0T0H.$$`*#AU/S_ZP``4.,,```*`!"=Y0`@E>4!,8+@!`"3
MY0``4.,!`8+G\___"@0P@^($()/E``!2XP0@@^3[__\:[?__ZIA"G^6`4I_E
M#1"@X00`H.'`_/_K``!0XPP```H`$)WE`""5Y0$Q@N`$`)/E``!0XP$!@N?S
M__\*!#"#X@0@D^4``%+C!""#Y/O__QKM___J3$*?Y3!2G^4-$*#A!`"@X:S\
M_^L``%#C#```"@`0G>4`()7E`3&"X`0`D^4``%#C`0&"Y_/__PH$,(/B!""3
MY0``4N,$((/D^___&NW__^H`0I_EX%&?Y0T0H.$$`*#AF/S_ZP``4.,,```*
M`!"=Y0`@E>4!,8+@!`"3Y0``4.,!`8+G\___"@0P@^($()/E``!2XP0@@^3[
M__\:[?__ZK1!G^6049_E#1"@X00`H.&$_/_K``!0XPP```H`$)WE`""5Y0$Q
M@N`$`)/E``!0XP$!@N?S__\*!#"#X@0@D^4``%+C!""#Y/O__QKM___J:$&?
MY4!1G^4-$*#A!`"@X7#\_^L``%#C#```"@`0G>4`()7E`3&"X`0`D^4``%#C
M`0&"Y_/__PH$,(/B!""3Y0``4N,$((/D^___&NW__^H<09_E\%"?Y0T0H.$$
M`*#A7/S_ZP``4.,,```*`!"=Y0`@E>4!,8+@!`"3Y0``4.,!`8+G\___"@0P
M@^($()/E``!2XP0@@^3[__\:[?__Z@T0H.',`)_E2OS_ZP`04.(!```*L`"?
MY?C\_^L-$*#AM`"?Y4/\_^L`$%#B`0``"J@`G^7Q_/_K#1"@X:``G^4\_/_K
M`!!0X@P```IP`)_EZOS_ZT@PG^4`()/E!#"=Y0(@,^``,*#C#```&G00G^5$
M`)_E#-"-XC!`O>C?_/_J#1"@X6``G^4J_/_K`!!0XN___PHL`)_EV/S_Z^S_
M_^K/^O_KU)T!`$1'`0`8H`$`4$<!`%A'`0!D1P$`;$<!`'Q'`0`81P$`B$<!
M`)1'`0"@1P$`)$<!`*Q'`0#`1P$`U$<!`.!'`0`$2`$`\$<!``'*H.,$X"WE
M#,!-X/`/C.5<,)_E#-!-XE@`G^4-$*#A`#"3Y00PC>4`,*#C!?S_ZP``4.,%
M```*``#0Y0``4.,P`%`3`0"@`P``H!,!`"#B'#"?Y0`@D^4$,)WE`B`SX``P
MH.,!```:#-"-X@3PG>2?^O_KU)T!`(A'`0`!RJ#C#P`MZ03@+>4,P$W@\`^,
MY3`0G^4,T$WB+,"?Y0``D>44,(WB$""=Y0$0H.,`P)SE!,"-Y0#`H.,`,(WE
ML_K_Z_\`H..]^O_K**`!`-2=`0``P*#C\$,MZ0'HH.,,P$W@#N!,X`'*3.(`
M`(SE#@!<X?O__QHX``[E`=A-XAS03>("$*#C`!"-Y0'HC>(\$9_E`""@XP`P
MH.,`$)'E%!".Y0`0H.,4X([B`)"@X8CZ_^L!8%#B`(#!XL@OH.'(/R;@`C!3
MX',P_^8","/@`C!3X`(@PN`#8%;@`H#(X```6.,R``"ZZ'"?Y0Q0C>(`$*#C
M!B"@X0@PH.$)`*#A`!"-Y7/Z_^L!`''C`0!P`RP```K`()_E!1"@X0D`H.$S
M^O_K`0!PXR0```H'`%#C&@``F@@`0.(`0)7@`P``.A8``.H!0$3B!0!4X1,`
M`#H((*#C!Q"@X00`H.$\^O_K``!0X_;__QH%0$3@!@"4X,0?J.`!R(WB5#"?
MY13`C.(`()/E`#"<Y0(@,^``,*#C#@``&@'8C>(<T(WB\(.]Z`%H5N(`@,CB
M`0!XXP$(=@/.__\:``#@XP`0H.'L___J&`"?Y8W__^L4`)_EB___ZRCZ_^O4
MG0$`"*`!``@``0`82`$`"$@!``'*H.,00"WI#,!-X/@/C.4`^O_K^?G_ZP``
M4.,``)`5$("]Z`'*H.-P0"WI#,!-X-@/C.7`,)_E&-!-X@!0H.$0$(WBM`"?
MY0`PD^44,(WE`#"@XV+[_^L`0%#B`@``"@`PU.4``%/C"@``&H@PG^4`()/E
M%#"=Y0(@,^``,*#C!1"@`70`GP4:```:&-"-XG!`O>@$_/_J!0"@X3'Z_^L`
M8*#A!`"@X2[Z_^L``(;@`@"`XAGZ_^M$P)_E1#"?Y0`@X.,!$*#C"$"-Y2`0
MC>@`8*#A,OK_ZQPPG^4`()/E%#"=Y0(@,^``,*#C!A"@`0@`GP7D__\*Y/G_
MZ]2=`0`D2`$`-$<!`#A'`0`!RJ#C\$\MZ0S`3>#H#HSEB#6?Y8@EG^7TT$WB
M`""2Y>P@C>4`(*#C`&"@X0<`D^B(4(WB#$"#XB3`@^('`(7HH."-X@\`M.B4
M<(WB#P"NZ`,`E.@#`([H!P"<Z`<`A^@8$(WB/`6?Y1K[_^L`0%#B`@``"@`P
MU.4``%/C^@``&J'Y_^N:^?_K``!0XV\```H`@)#E``!8XVP```H(`*#A[?G_
MZX``H.$!`(#BV/G_ZP#`V.4``%SC`$"@X0!PH.$*```*X)2?Y00`H.$`P(WE
M"3"@X0`@X.,!$*#C[?G_ZP'`^.4"0(3B``!<X_7__QJX!)_EH("-X@(``.H$
M`+CE``!0XPT```H8$(WB\?K_ZP!`4.+X__\*`##4Y0``4^/U__\*(?O_ZP``
M4./R__\*!`"@X8_Y_^L`0%#B#```&@1`E>0``%3C"0``"@`PU.4``%/CM0``
M"@0`H.$3^__K``!0X_'__QH$0)7D``!4X_7__QH$`*#AM_G_ZS"4G^4`H*#A
M!P"@X;/Y_^L`H(K@`:N*X@2@BN(*`*#AG/G_ZQ`TG^4`(.#C`1"@XP@PC>4,
M<(WE`#2?Y0!`C>4$D(WE`("@X;/Y_^L'':#C"`"@X;GY_^L!`'#C`P``&JKY
M_^L`$)#E$0!1XY8``!H8$(WB"`"@X='Y_^L`4%#B)P``"K@3G^4`,);EM".?
MY0``D>4!$*#C`("-Y;GY_^L`<*#C?#.?Y0`@D^7L,)WE`B`SX``PH./6```:
M!P"@X?30C>+PC[WH2_G_ZP"`4.)Y```:!`"7Y```4.,)```*&!"-XISZ_^L`
M,%#B^/__"@`PT^4``%/C\O__&@0`E^0``%#C]?__&@T`H.-A^?_K-(.?Y5/`
MH.,`0*#A`'"@X8C__^HH,)WE#SH#X@$)4^/3__\:,$"=Y13Y_^L``%3AS___
M&B@PG>6#.Z#AHSN@X0<-4^/*__\:"@"@X4WY_^L8$(WB`'"@X>`"G^5Z^O_K
M`!!0XF@```H``);E6OS_ZP"@4.)D```*"@"@X5/Y_^L#`%#C`$"@X0L``)H$
M`$#BK!*?Y0``BN#O^/_K``!0XP4``!H$`%3CB```"@1`BN`%,%3E+P!3XX0`
M``J$`I_E&!"-XF#Z_^L``%#C`P``"@`PT.4P`%/C``!3$P0``!H*`*#A`!"@
MXR/Y_^L`0%#B1P``&E`2G^5(`I_E!/O_ZRSY_^M$8I_E1#*?Y0`@X.,!$*#C
M\(#-X0Q@C>4THI_E"`"-Y0<`H.$W^?_K#@``ZC+Y_^L`,)#E$0!3XQ```!H<
M^?_K`1"@XP%0A>`*,*#A!""@X1!@C>4,4(WE`,"@X0<`H.$`$XWH)_G_ZP<=
MH.,'`*#A+?G_ZP$`<.,`0*#AZO__"@@`H.'"^/_KB`&?Y0<0H.'>^O_K!P"@
MX;K^_^M[___J`T"@X4[__^H'^?_K@`"@X0$`@.(8___J<`&?Y0`PEN60(9_E
M``"0Y000C>4`@(WE`1"@XR;Y_^MK___JJ?[_ZRPQG^4`()/E[#"=Y0(@,^``
M,*#C0@``&@0`H.'TT(WB\$^]Z+?X_^H`H);EF/__ZB[^_^L`H%'B`&"@X;/_
M_[H*(%#B`+"@XP`PRN($`*#A`+"-Y<;X_^L&(*#CN!"-X@0`H.&)^/_K!@!0
MXRT``!H$,9_EN""=Y0,`4N&C__\:O"O=X?0PG^4#`%+AG___&C(@5N(`,,KB
M!`"@X0"PC>6S^/_K!`"@X<!`C>(H(*#C!!"@X77X_^LH`%#C&0``&J0@G^6X
M,)_E#""-Y0$0H.,`(.#C!P"@X0A`C>7P@,WAZ+#-Y<_X_^NL___J!$"6Y0``
M5.-W__\*!`"@X;KX_^L#`%#C<___F@0`0.)T$)_E``"$X%?X_^L``%#C!*"@
M`6S__^IZ^/_K7`"?Y=K]_^N$AP$`U)T!`!A'`0`\2`$`U$<!`$!'`0!02`$`
M1$@!`"B@`0"42`$`-$@!`.A(`0#P2`$`B$<!``1(`0#420$`'$D!`"Q)`0!8
M2`$``$-!0TA%```,20$`^$@!``!)`0`!RJ#C<$`MZ0S`3>#H#XSE)"*?Y0C0
M3>(@,I_E`""2Y00@C>4`(*#CNP0`ZP,PG^<-$*#A`T"0YP0"G^5H,-3E:3#$
MY:/Y_^L``%#C`@``"@`PT.4Q`%/C80``"FK\_^O@,9_EK`0`ZP,PG^<#0)#G
M!`"@X=`1G^4#,*#C`2"@XVGX_^L`0%#B#0``"KPQG^40()3EH`0`ZP,PG^<`
M$)+E`%"@X:@AG^4#`)#G0_C_ZQ`PE.4`$)/E"#"1Y0$%$^-2```:C"&?Y9,$
M`.N($9_E`B"?YP!0H.$#,*#C`@"0YP$@H.-0^/_K`$!0X@H```IH`9_E#1"@
MX7;Y_^L`(%#B.P``"E@QG^40$)3E`S"?YP`0D>4#`)7G*/C_ZT11G^5$,9_E
M?`0`ZT`1G^4#,)_G`$"@X0$@H.,#8)#G!@"@X4[X_^LH(9_E`!"@X08`H.$:
M^/_K'#&?Y0`@H.,8`9_E`S"?YPT0H.$#,)3G:2##Y5CY_^L``%#C`$"@X0@`
MA>4/```*!QV@XP0`H.%*^/_K`2"`XA$`4.,!`%(3`#"@X2```(J0,)_E`""3
MY00PG>4"(#/@`#"@XQD``!H(T(WB<("]Z`0`E>4,_O_K``!0XP!`H.$(`(7E
MZ?__&IP`G^4O^/_K`3#0Y0``4^.?__\*F?__ZFQ0G^40()3E!#"5Y0``DN4`
M$)/E9_K_Z\/__^IL,)_E`S"?YP,`E><R^/_KI___ZM;W_^L$()7E5`"?Y0`0
MDN4$(*#A&?C_Z]2=`0#<;```;$<!`*!L``!`20$`<&P``$1)`0`X;```3$D!
M`"1'`0#\:P``,*`!`-QK``!020$`:$D!`*AK```81P$`<$D!`/1J``"420$`
M`<J@XS!`+>D,P$W@Z`^,Y>`PG^4,T$WB`$"@X0T0H.'4`)_E`#"3Y00PC>4`
M,*#C!?G_ZP`P4.(*```*`##3Y0``4^,P`%,3`3"@`P`PH!,!,"/B``!4XP`P
MH`,!,`,2``!3XP<``!J(,)_E`""3Y00PG>4"(#/@`#"@XQP``!H,T(WB,("]
MZ``PU.4``%/C]/__"@0`H.%H^__K+Q"@XP!0H.$(^/_K``!0XP%0@!(%`*#A
MC/?_ZT`0G^4$(*#C#?C_ZP``4./F__\:)#"?Y0`@D^4$,)WE`B`SX``PH.,#
M```:!`"@X0S0C>(P0+WH+_G_ZG_W_^O4G0$`B$<!`%!(`0```````<J@X_!/
M+>D,P$W@2`V,Y20\G^6EWTWB`!"@X8!@@>)``(#B"""-X@`PD^6,,HWE`#"@
MXP!0H.,$P!#E".`0Y0@`@.(L-*#A_SP#XBP\@^$,1*#A##R#X?](!.(^S[_F
M!#"#X08`4.$`P(+E!%""Y0@P@N4,4(+E$"""XNW__QHA/HWB`#"-Y8`PG>4$
M$(WE<("=Y70@G>40L)WE>'"=Y7Q@G>6$P)WE"%"=Y0Q`G>44H)WE$`"-X@,0
MH.$!``#J";"@X0.@H.$!,*#A/."0Y3@0D.4(D+#E"1`AX`@0(>`'@*#A`W"@
MX0`PH.-T,(#E!#"0Y040(>`#X"[@`N`NX`3@+N`&(*#A#&"@X:'/H.&.P(SA
M`1"1X`P0@>$`P)WE"U"@X0``7.$*0*#A`,"@XW`0@.7A__\:!!"=Y?PZG^4(
M()WE`)"1Y0$(D>D@P)'E`R"2X`P@DN"IS:#A$("1Y1B@D>6`PHSA#$"1Y8G"
MC.$"P)S@"B`HX"OAH.$+(`+@"B`BX`3OCN$"P)S@"^^.X1`@G>4I0:#A`$^$
MX0X`*.`#()+@"0``X`@`(.`*()+@"4^$X0`@DN`8`)WE!%`NX`,`D.`,4`7@
M["V"X`Y0)>`(`)#@!0"0X.)=@.`@`)WEL&"=Y0,`D.`.`)#@;.$DX`+@#N`$
MX"[@#N"0X"@`G>5B(:#A`P"0X`0`D.!L02+@!4`$X.7MCN!L023@!`"0X.Y-
M@.`P`)WE`P"0X&P!@.!EP2+@#L`,X`+`+.`,`)#@.,"=Y6[AH.$#P)S@`B"<
MX&7!+N`$P`S@Y`V`X&7!+.`,()+@X,V"X$`@G>4#()+@92&"X&11+N``4`7@
M#E`EX`4@DN!(4)WE8`&@X0-0E>`.X)7@9%$@X`Q0!>#L+8+@9%$EX`7@GN#B
M78[@4."=Y0/@GN!DX8[@;$$@X`)`!.``0"3@!.">X%A`G>5B(:#A`T"4X```
ME.!L02+@!4`$X.7MCN!L023@!`"0X.Y-@.!@`)WE`P"0X&P!@.!EP2+@#L`,
MX`+`+.`,`)#@:,"=Y6[AH.$#P)S@`B"<X&7!+N`$P`S@Y`V`X&7!+.`,()+@
MX,V"X'`@G>4#()+@92&"X&11+N``4`7@#E`EX`4@DN!X4)WE8`&@X0-0E>`.
MX)7@9%$@X`Q0!>#L+8+@9%$EX`7@GN#B78[@@."=Y0/@GN!DX8[@;$$@X`)`
M!.``0"3@!$">X(C@G>5B(:#A`^">X```GN!LX2+@!>`.X.5-A.!LX2[@#@"0
MX.3M@."0`)WE`P"0X&P!@.!EP2+@!,`,X`+`+.`,`)#@F,"=Y61!H.$#P)S@
M`B"<X&7!).`.P`S@[@V`X&7!+.`,()+@X,V"X*`@G>4#,)+@;B$DX``@`N`$
M("+@93&#X`(PD^#L+8/@J%"=Y1@XG^5@`:#A`U"5X`10E>!N02#@#$`DX`1`
ME>`#4);@;E&%X+A@G>5LX2#@`N`NX.)-A.`.X)7@8B&@X0-0EN``4)7@P&"=
MY6P!(N#D[8[@!``@X```E>`#8);@[EV`X&S!AN!D`2+@R&"=Y0X`(.```)S@
M;N&@X0/`EN`"P)S@T&"=Y60A+N`%("+@Y0V`X`(@G.`#P);@9,&,X-A@G>5E
M02[@X"V"X`!`).`$0)S@8`&@X0/`EN`.P)S@X&"=Y>+MA.!E02#@`D`DX`1`
MG.`#P);@9<&,X.A@G>5B42#@#E`EX`50G.!NP:#A`V"6X.Y-A.```);@8N$L
MX/!@G>4$X"[@#N"0X`-@EN#D787@9`$LX&(AAN#X8)WE!0`@X.7MCN``()+@
M90&@X0-@EN`,8);@9,$@X.XM@N``<9WE#L`LX`S`EN#B;8S@`W"7X`A1G>5N
MP2#@9$&'X`+`+.`,P)3@8B&@X0-`E>``0)3@$%&=Y6X!(N#FS8S@!@`@X```
ME.`#4)7@[$V`X&[AA>!F`2+@&%&=Y0P`(.```)[@;,&@X0/@E>`"X)[@(%&=
MY68A+.`$("+@`B">X`/@E>#D#8#@9N&.X&11+.`H89WE`%`EX.`M@N`%4)[@
M8`&@X0-@EN`,P);@9.$@X#!AG>4"X"[@XEV%X`[@G.`#P);@9,&,X#AAG>5B
M02#@Y>V.X`5`).`$0)S@95&@X0/`EN``P)S@0&&=Y>X-A.!B027@#D`DX`1`
MG.`#,);@8C&#X&XA)>``("+@`B"3X$C!G>7,-9_EX$V$X`/`G.!@`:#A!<"<
MX&Y1@.%N80#@4'&=Y010!>`&4(7A!<"<X`-0E^#D+8+@;E&%X&3A@.%D80#@
M6'&=Y0+@#N#BS8S@!N".X6(AH.$%4)[@`^"7X`#@GN#L#87@9%&"X61A`N`,
M4`7@8'&=Y090A>$.4)7@;.&"X0-PE^!L80+@`.`.X.!=A>!D08?@!N".X03@
MGN#E;8[@:.&=Y6`!H.$#X)[@`B">X&SA@.%L00#@<'&=Y07@#N`$X([A`N">
MX`-PE^!E(8#AYDV.X&S!A^!EX0#@>'&=Y08@`N`.((+A9F&@X0S`DN`#()?@
M`""2X.0-C.!EP8;A9>$&X(!QG>4$P`S@#L",X0+@G.`#P)?@9"&&X67!C.``
M(`+@9%$&X.#MCN`%((+A#""2X.[-@N"((9WE8`&@X611@.$#()+@!B"2X)!Q
MG>5D80#@#E`%X`90A>$"4)7@`W"7X&XA@.%N80#@9$&'X`P@`N"8<9WE[%V%
MX`8@@N%LP:#A!$"2X`,@E^``()+@Y0V$X&Y!C.%N80S@!4`$X*!QG>4&0(3A
M`D"4X&4AC.'@;83@`W"7X&5!#.``(`+@;N&'X`0@@N$.()+@YNV"X*@AG>5@
M`:#A`R"2X`P@DN!EP8#A94$`X+!QG>4&P`S@!,",X0)`G.`#P)?@9B&`X;AQ
MG>5EP8S@#B`"X&91`.#N383@!2""X6[AH.$,P)+@`R"7X``@DN#D#8S@9L&.
MX691#N#`<9WE!,`,X`7`C.$"4)S@`\"7X&0ACN%FP8S@`"`"X&1A#N#@787@
M!B""X0P@DN#ES8+@R"&=Y6`!H.$#()+@`&"@XPX@DN!DX8#AT'&=Y07@#N`$
M8('E#&"!Y11@@>4<8('E9&$`X`;@CN$"X)[@`W"7X&4A@.%E80#@9$&'X`P@
M`N#8<9WE!B""X>SMCN`$0)+@;,&@X0,@E^``()+@90&,X65A#.`.``#@X'&=
MY08`@.'N383@`@"0X&XAC.$#<)?@;F$,X`0@`N#0,I_EY`V`X&51A^`&((+A
MZ'&=Y61!H.$%()+@X%V"X/!AG>5N(23@`W"7X`S`E^``("+@`B"<X`/`EN!N
MP8S@^&&=Y>7M@N!@(23@!2`BX`(@G.!E4:#A`V"6X`1`EN!@P27@`&*=Y0[`
M+.`,P)3@`T"6X.XM@N!@083@"&*=Y6X!)>`"`"#@XLV,X```E.!B(:#A`V"6
MX`50EN!N02+@$&*=Y0Q`).`$0)7@`U"6X.P-@.`88IWE;E&%X&SA(N``X"[@
MX$V$X`[@E>!@`:#A`U"6X`)0E>`@8IWE;"$@X.3MCN`$("+@`B"5X`-@EN#N
M78+@;,&&X&0A(.`H8IWE#B`BX`(@G.!NX:#A`\"6X`#`G.`P8IWE9`$NX.4M
M@N`%`"#@``"<X`/`EN!DP8S@.&*=Y>)-@.!E`2[@`@`@X```G.!B(:#A`V"6
MX`[@EN!EP2+@0&*=Y>0-@.`$P"S@#,">X`/@EN!EX8[@2&*=Y>!=C.!DP2+@
M`,`LX`S`GN!@`:#A`^"6X`+@GN!08IWE9"$@X.7-C.`%("+@`B">X`/@EN!D
MX8[@6&*=Y>Q-@N!E(2#@#"`BX`(@GN!LP:#A`^"6X`#@GN!@8IWE90$LX.0M
M@N`$`"#@``">X`/@EN!EX8[@:&*=Y>)=@.!D`2S@`@`@X```GN!B(:#A`^"6
MX`S@GN!P8IWE9,$BX`7`+.`,P)[@`^"6X.4-@.!DX8[@96$BX'A"G>4`8";@
MX,V,X`;@GN!@`:#A`T"4X`(@E.!E82#@@$*=Y0Q@)N#L[8[@!B"2X`,PE.!L
MH8K@"3"3X&S!(.#N+8+@#L`LX&4Q@^`,,)/@XCV#X"#`D>4+()+@;H&(X``P
M@>48H('E$("!Y0@@@>4L,)_E#`"0X`!@H.,@`('E)&"!Y0`@D^6,,IWE`B`S
MX``PH.,!```:I=^-XO"/O>AL]/_KU)T!`)EY@EJAZ]ENW+P;C];!8LH!RJ#C
M$$`MZ0S`3>#X#XSE@`"@XX7T_^L.>Y_M`""@XP![@.T->Y_M>""`Y0)[@.T,
M>Y_M!'N`[0Q[G^T&>X#M#'N?[0A[@.T,>Y_M"GN`[0Q[@.T0@+WH`2-%9P``
M``")J\WO`````/[<NI@`````=E0R$`````#PX=+#`````````````````<J@
MX_!'+>D,P$W@X`^,Y2@PD.4"D*#A+""0Y8G!@^`#`%SA`#"@XP(@T^``4*#A
M,""0Y0%`H.$T$)#ER0^@X0$``"H!()+B`!"AXBPPA>6I/J#A@#&#X0(PD^"@
M'J'@>`"5Y2C`A>4``%#C.("%`C`PA>4T$(7E(0``&C\`6>,Q``#:0)!)XBEC
MH.$!<(;B!W.$X`00H.$(,*#A0$"$X@#@D>4$P)'E"`"1Y0P@D>40$('B!`!1
MX0#@@^4$P(/E"`"#Y0P@@^40,(/B\___&@%`H.$%`*#ADOS_ZP<`5.'K__\:
M!FUFX`:3B>`)(*#A!Q"@X0@`H.'Q\__K>)"%Y?"'O>A`<&#B"0!7X0EPH*$X
M@(7B``"(X`<@H.$$$*#AY_/_ZW@PE>4#,(?@0`!3XW@PA>7PA[T8!0"@X0>0
M2>`'0(3@=_S_Z\O__^H$<*#AY?__Z@'*H./P02WI#,!-X.@/C.4H,)'E,'"1
MY3B`@>*C(:#A/R`"XC-OO^8!,(+B`4"@X3@`4^-_$.#C`%"@X3=_O^8"$,CG
M/0``VD`@8^(`$*#C`P"(X"OT_^L$`*#A7/S_ZS@@H.,`$*#C"`"@X27T_^L$
M`*#A<'"$Y71@A.54_/_K`S#4Y00`H.$`,,7ELC#4X0$PQ>4`,)3E(S2@X0(P
MQ>4`,)3E`S#%Y0LPU.4$,,7ENC#4X04PQ>4(,)3E(S2@X08PQ>4(,)3E!S#%
MY1,PU.4(,,7ELC'4X0DPQ>40,)3E(S2@X0HPQ>40,)3E"S#%Y1LPU.4,,,7E
MNC'4X0TPQ>48,)3E(S2@X0XPQ>48,)3E#S#%Y2,PU.40,,7ELC+4X1$PQ>4@
M,)3E(S2@X1(PQ>4@,)3E$S#%Y?!!O>B(\__J`P"(X#@@8^(`$*#C[?/_Z\;_
M_^H```````````\*X.,?\$#B"#"?Y0,PC^``,)/EEO/_ZO!9```(0"WI"("]
MZ`$``@`^````00````P```!!````$0```$$````G````00```#8```!!````
M`P```$$````&````00```!4```!!````#P```$$````.````00```"8```!!
M````$P```$$````I````00````(```!!````&0```$$````*````00````L`
M``!!```````````````E<R\E<P```"]P<F]C+W-E;&8O97AE``!$>6YA3&]A
M9&5R.CIB;V]T7T1Y;F%,;V%D97(`26YT97)N86QS.CI005(Z.D)/3U0`````
M+W!R;V,O)6DO)7,`97AE`"X```!005)?5$5-4`````!005)?4%)/1TY!344`
M````.@```"5S)7,E<P``+P```%!%4DPU3$E"`````%!%4DQ,24(`4$523#5/
M4%0`````4$523$E/``!005)?24Y)5$E!3$E:140`4$%27U-005=.140`4$%2
M7T-,14%.````4$%27T1%0E5'````4$%27T-!0TA%````4$%27T=,3T)!3%]$
M14)51P````!005)?1TQ/0D%,7U1-4$1)4@```%!!4E]435!$25(``%!!4E]'
M3$]"04Q?5$5-4`!005)?1TQ/0D%,7T-,14%.`````#$```!L<V5E:R!F86EL
M960`````<F5A9"!F86EL960`3$1?3$E"4D%265]0051(`%-94U1%30``)3`R
M>``````E<R5S)7,E<P````!P87(M`````"5S.B!C<F5A=&EO;B!O9B!P<FEV
M871E('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H``"5S.B!P
M<FEV871E('-U8F1I<F5C=&]R>2`E<R!I<R!U;G-A9F4@*'!L96%S92!R96UO
M=F4@:70@86YD(')E=')Y('EO=7(@;W!E<F%T:6]N*0H``%!!5$@`````<&%R
M;``````N<&%R`````'-H;W)T(')E860``"5S)7-C86-H92TE<R5S```E<R5S
M=&5M<"TE=25S````)7,E<W1E;7`M)74M)74E<P`````8````<&5R;``````P
M````4$%2.CI086-K97(Z.E9%4E-)3TX`````,2XP-C,```!5;F%B;&4@=&\@
M8W)E871E(&-A8VAE(&1I<F5C=&]R>0`````E<SH@8W)E871I;VX@;V8@<')I
M=F%T92!C86-H92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*
M`````"UE```M+0``55-%4@````!54T523D%-10````!414U01$E2`%1-4``O
M=&UP`````&5V86P@)V5X96,@+W5S<B]B:6XO<&5R;"`@+5,@)#`@)'LQ*R(D
M0")])PII9B`P.R`C(&YO="!R=6YN:6YG('5N9&5R('-O;64@<VAE;&P*<&%C
M:V%G92!?7W!A<E]P;#L*;7D@*"1005)?34%'24,L("1&24Q%7V]F9G-E=%]S
M:7IE+"`D8V%C:&5?;F%M95]S:7IE*3L*0D5'24X@>PHD4$%27TU!1TE#(#T@
M(EQN4$%2+G!M7&XB.PHD1DE,15]O9F9S971?<VEZ92`](#0[("`@(R!P86-K
M*").(BD*)&-A8VAE7VYA;65?<VEZ92`](#0P.PHD4$M:25!?34%'24,@/2`B
M4$M<,#`S7#`P-"(["GT*<W5B(&9I;F1?<&%R7VUA9VEC"GL*;7D@*"1F:"D@
M/2!`7SL*;7D@)&-H=6YK7W-I>F4@/2`V-"`J(#$P,C0["FUY("1B=68["FUY
M("1S:7IE(#T@+7,@)&9H.PIM>2`D<&]S(#T@*"1S:7IE+3$I("T@*"1S:7IE
M+3$I("4@)&-H=6YK7W-I>F4[("`@("`@(R!.3U1%.B`D<&]S(&ES(&$@;75L
M=&EP;&4@;V8@)&-H=6YK7W-I>F4*=VAI;&4@*"1P;W,@/CT@,"D@>PIS965K
M("1F:"P@)'!O<RP@,#L*<F5A9"`D9F@L("1B=68L("1C:'5N:U]S:7IE("L@
M;&5N9W1H*"1005)?34%'24,I.PII9B`H*&UY("1I(#T@<FEN9&5X*"1B=68L
M("1005)?34%'24,I*2`^/2`P*2!["G)E='5R;B`D<&]S("L@)&D["GT*)'!O
M<R`M/2`D8VAU;FM?<VEZ93L*?0IR971U<FX@+3$["GT*;7D@*"1P87)?=&5M
M<"P@)'!R;V=N86UE+"!`=&UP9FEL92P@)4UO9'5L94-A8VAE*3L*14Y$('L@
M:68@*"1%3E9[4$%27T-,14%.?2D@>PIR97%U:7)E($9I;&4Z.E1E;7`["G)E
M<75I<F4@1FEL93HZ0F%S96YA;64["G)E<75I<F4@1FEL93HZ4W!E8SL*;7D@
M)'1O<&1I<B`]($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1P87)?=&5M<"D[
M"F]U=',H<7%;4F5M;W9I;F<@9FEL97,@:6X@(B1P87)?=&5M<")=*3L*1FEL
M93HZ1FEN9#HZ9FEN9&1E<'1H*'-U8B![("@@+60@*2`_(')M9&ER(#H@=6YL
M:6YK('TL("1P87)?=&5M<"D["G)M9&ER("1P87)?=&5M<#L*:68@*"UD("1P
M87)?=&5M<"`F)B`D7D\@;F4@)TU35VEN,S(G*2!["FUY("1T;7`@/2!N97<@
M1FEL93HZ5&5M<"@*5$5-4$Q!5$4@/3X@)W1M<%A86%A8)RP*1$E2(#T^($9I
M;&4Z.D)A<V5N86UE.CID:7)N86UE*"1T;W!D:7(I+`I3549&25@@/3X@)RYC
M;60G+`I53DQ)3DL@/3X@,"P**3L*;7D@)&9I;&5N86UE(#T@)'1M<"T^9FEL
M96YA;64["G!R:6YT("1T;7`@/#PB+BXN(CL*>#TQ.R!W:&EL92!;(%PD>"`M
M;'0@,3`@73L@9&\*<FT@+7)F("<D<&%R7W1E;7`G"FEF(%L@7"$@+60@)R1P
M87)?=&5M<"<@73L@=&AE;@IB<F5A:PIF:0IS;&5E<"`Q"G@]8&5X<'(@7"1X
M("L@,6`*9&]N90IR;2`G)&9I;&5N86UE)PHN+BX*8VQO<V4@)'1M<#L*8VAM
M;V0@,#<P,"P@)&9I;&5N86UE.PIM>2`D8VUD(#T@(B1F:6QE;F%M92`^+V1E
M=B]N=6QL(#(^)C$@)B(["G-Y<W1E;2@D8VUD*3L*;W5T<RAQ<5M3<&%W;F5D
M(&)A8VMG<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z("1F:6QE
M;F%M95TI.PI]"GT@?0I"14=)3B!["DEN=&5R;F%L<SHZ4$%2.CI"3T]4*"D@
M:68@9&5F:6YE9"`F26YT97)N86QS.CI005(Z.D)/3U0["F5V86P@>PI?<&%R
M7VEN:71?96YV*"D["FUY("1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["FUY
M("5S>7,@/2`H"G!A=&A?<V5P("`@(#T^("@D7D\@/7X@+UY-4U=I;B\@/R`G
M.R<@.B`G.B<I+`I?97AE("`@("`@("`]/B`H)%Y/(#U^("]>*#\Z35-7:6Y\
M3U,R?&-Y9W=I;BDO(#\@)RYE>&4G(#H@)R<I+`I?9&5L:6T@("`@("`]/B`H
M)%Y/(#U^("]>35-7:6Y\3U,R+R`_("=<7"<@.B`G+R<I+`HI.PI?<V5T7W!R
M;V=N86UE*"D["F]U=',H<7%;7"1P<F]G;F%M92`]("(D<')O9VYA;64B72D[
M"E]S971?<&%R7W1E;7`H*3L*;W5T<RAQ<5M<)$5.5GM005)?5$5-4'T@/2`B
M)$5.5GM005)?5$5-4'TB72D["FUY("@D<W1A<G1?<&]S+"`D<W1A<G1?;V9?
M1DE,15]S96-T:6]N*3L*34%'24,Z('L*;&]C86P@)%-)1WM?7U=!4DY?7WT@
M/2!S=6(@>WT["G5N;&5S<R`H;W!E;B!?1D@L("<\.G)A=R<L("1P<F]G;F%M
M92D@>PIO=71S*'%Q6T-A;B=T(')E860@9G)O;2!F:6QE("(D<')O9VYA;64B
M72D[("`C(&1O;B=T('5S92`D(2!H97)E(&%S(&ET(')E<75I<F5S($5R<FYO
M+G!M"FQA<W0@34%'24,["GT*;7D@)&UA9VEC7W!O<R`](&9I;F1?<&%R7VUA
M9VEC*"I?1D@I.PII9B`H)&UA9VEC7W!O<R`\(#`I('L*;W5T<RAQ<5M#86XG
M="!F:6YD(&UA9VEC('-T<FEN9R`B)%!!4E]-04=)0R(@:6X@9FEL92`B)'!R
M;V=N86UE(ETI.PIL87-T($U!1TE#.PI]"F]U=',H(D9O=6YD(%!!4B!M86=I
M8R!A="!P;W-I=&EO;B`D;6%G:6-?<&]S(BD["G-E96L@7T9(+"`D;6%G:6-?
M<&]S("T@)$9)3$5?;V9F<V5T7W-I>F4@+2!L96YG=&@H(EPP0T%#2$4B*2P@
M,#L*<F5A9"!?1D@L("1B=68L(&QE;F=T:"@B7#!#04-(12(I.PII9B`H)&)U
M9B!N92`B7#!#04-(12(@)B8@)&)U9B!N92`B7#!#3$5!3B(I('L*;W5T<R@B
M3F\@8V%C:&4@;6%R:V5R(&9O=6YD(BD["FQA<W0@34%'24,["GT*;W5T<RAQ
M<5M#86-H92!M87)K97(@(B1B=68B(&9O=6YD72D["G-E96L@7T9(+"`D;6%G
M:6-?<&]S("T@)$9)3$5?;V9F<V5T7W-I>F4L(#`["G)E860@7T9(+"`D8G5F
M+"`D1DE,15]O9F9S971?<VEZ93L*;7D@)&]F9G-E="`]('5N<&%C:R@B3B(L
M("1B=68I.PIO=71S*")/9F9S970@9G)O;2!S=&%R="!O9B!&24Q%<R!I<R`D
M;V9F<V5T(BD["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@)$9)3$5?;V9F<V5T
M7W-I>F4@+2`D;V9F<V5T+"`P.PHD<W1A<G1?;V9?1DE,15]S96-T:6]N(#T@
M=&5L;"!?1D@["FUY("5R97%U:7)E7VQI<W0["G)E860@7T9(+"`D8G5F+"`T
M.R`@("`@("`@("`@("`@("`@("`@("`@("`@(",@<F5A9"!T:&4@9FER<W0@
M(D9)3$4B"G=H:6QE("@D8G5F(&5Q(")&24Q%(BD@>PIR96%D(%]&2"P@)&)U
M9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PIM>2`D
M9G5L;&YA;64@/2`D8G5F.PIO=71S*'%Q6U5N<&%C:VEN9R!&24Q%("(D9G5L
M;&YA;64B+BXN72D["FUY("1C<F,@/2`H("1F=6QL;F%M92`]?B!S?%XH6V$M
M9EQD77LX?2DO?'P@*2`_("0Q(#H@=6YD968["FUY("@D8F%S96YA;64L("1E
M>'0I(#T@*"1B=68@/7X@;7PH/SHN*B\I/R@N*BDH7"XN*BE\*3L*<F5A9"!?
M1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F
M*3L*:68@*&1E9FEN960H)&5X="D@86YD("1E>'0@(7X@+UPN*#\Z<&U\<&Q\
M:7A\86PI)"]I*2!["FUY("1F:6QE;F%M92`](%]S879E7V%S*"(D8W)C)&5X
M="(L("1B=68L(#`W-34I.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F=6QL
M;F%M97T@/2`D9FEL96YA;64["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9I
M;&5N86UE?2`]("1F=6QL;F%M93L*?0IE;'-E('L*)$UO9'5L94-A8VAE>R1F
M=6QL;F%M97T@/2!["F)U9B`]/B`D8G5F+`IC<F,@/3X@)&-R8RP*;F%M92`]
M/B`D9G5L;&YA;64L"GT["B1R97%U:7)E7VQI<W1[)&9U;&QN86UE?2LK.PI]
M"G)E860@7T9(+"`D8G5F+"`T.PI]"FQO8V%L($!)3D,@/2`H<W5B('L*;7D@
M*"1S96QF+"`D;6]D=6QE*2`]($!?.PIR971U<FX@:68@<F5F("1M;V1U;&4@
M;W(@(21M;V1U;&4["FUY("1I;F9O(#T@)$UO9'5L94-A8VAE>R1M;V1U;&5]
M.PIR971U<FX@=6YL97-S("1I;F9O.PID96QE=&4@)')E<75I<F5?;&ES='LD
M;6]D=6QE?3L*)$E.0WLD;6]D=6QE?2`]("(O;&]A9&5R+R1I;F9O+R1M;V1U
M;&4B.PII9B`H)$5.5GM005)?0TQ%04Y](&%N9"!D969I;F5D*"9)3SHZ1FEL
M93HZ;F5W*2D@>PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W7W1M<&9I;&4@;W(@
M9&EE(")#86XG="!C<F5A=&4@=&5M<"!F:6QE.B`D(2(["B1F:"T^8FEN;6]D
M92@I.PHD9F@M/G!R:6YT*"1I;F9O+3Y[8G5F?2D["B1F:"T^<V5E:R@P+"`P
M*3L*<F5T=7)N("1F:#L*?0IE;'-E('L*;7D@)&9I;&5N86UE(#T@7W-A=F5?
M87,H(B1I;F9O+3Y[8W)C?2YP;2(L("1I;F9O+3Y[8G5F?2D["B1I;F9O+3Y[
M9FEL97T@/2`D9FEL96YA;64["F]P96X@;7D@)&9H+"`G/#IR87<G+"`D9FEL
M96YA;64@;W(@9&EE('%Q6T-A;B=T(')E860@(B1F:6QE;F%M92(Z("0A73L*
M<F5T=7)N("1F:#L*?0ID:64@(D)O;W1S=')A<'!I;F<@9F%I;&5D.B!C86XG
M="!F:6YD(&UO9'5L92`D;6]D=6QE(2(["GTL($!)3D,I.PIR97%U:7)E(%A3
M3&]A9&5R.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@0V%R<#HZ2&5A
M=GD["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI
M=%]D>6YA;&]A9&5R*"D["G)E<75I<F4@24\Z.D9I;&4["G=H:6QE("AM>2`D
M9FEL96YA;64@/2`H<V]R="!K97ES("5R97%U:7)E7VQI<W0I6S!=*2!["G5N
M;&5S<R`H)$E.0WLD9FEL96YA;65](&]R("1F:6QE;F%M92`]?B`O0E-$4$%.
M+RD@>PII9B`H)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI('L*<F5Q=6ER92`D
M9FEL96YA;64["GT*96QS92!["F1O("1F:6QE;F%M92!U;FQE<W,@)&9I;&5N
M86UE(#U^("]S:71E8W5S=&]M:7IE7"YP;"0O.PI]"GT*9&5L971E("1R97%U
M:7)E7VQI<W1[)&9I;&5N86UE?3L*?0II9B`H)&)U9B!N92`D4$M:25!?34%'
M24,I('L*;W5T<RAQ<5M.;R!Z:7`@9F]U;F0@869T97(@1DE,12!S96-T:6]N
M(&EN(&9I;&4@(B1P<F]G;F%M92)=*3L*;&%S="!-04=)0R`["GT*)'-T87)T
M7W!O<R`]("AT96QL(%]&2"D@+2`T.R`@("`@("`@("`@("`@("`C('-T87)T
M(&]F('II<`I]"FUY($!P87)?87)G<SL*;7D@*"1O=70L("1B=6YD;&4L("1L
M;V=F:"P@)&-A8VAE7VYA;64I.PID96QE=&4@)$5.5GM005)?05!07U)%55-%
M?3L@(R!S86YI=&EZ92`H4D554T4@;6%Y(&)E(&$@<V5C=7)I='D@<')O8FQE
M;2D*:68@*"$D<W1A<G1?<&]S(&]R("@D05)'5ELP72!E<2`G+2UP87(M;W!T
M:6]N<R<@)B8@<VAI9G0I*2!["FUY("5D:7-T7V-M9"`]('%W*`IP("`@8FQI
M8E]T;U]P87(*:2`@(&EN<W1A;&Q?<&%R"G4@("!U;FEN<W1A;&Q?<&%R"G,@
M("!S:6=N7W!A<@IV("`@=F5R:69Y7W!A<@HI.PII9B`H0$%21U8@86YD("1!
M4D=66S!=(&5Q("<M+7)E=7-E)RD@>PIS:&EF="!`05)'5CL*)$5.5GM005)?
M05!07U)%55-%?2`]('-H:69T($!!4D=6.PI]"F5L<V4@>R`C(&YO<FUA;"!P
M87)L(&)E:&%V:6]U<@IM>2!`861D7W1O7VEN8SL*=VAI;&4@*$!!4D=6*2![
M"B1!4D=66S!=(#U^("]>+2A;04E-3T),8G%P:75S5'9=*2@N*BDO(&]R(&QA
M<W0["FEF("@D,2!E<2`G22<I('L*<'5S:"!`861D7W1O7VEN8RP@)#(["GT*
M96QS:68@*"0Q(&5Q("=-)RD@>PIE=F%L(")U<V4@)#(B.PI]"F5L<VEF("@D
M,2!E<2`G02<I('L*=6YS:&EF="!`<&%R7V%R9W,L("0R.PI]"F5L<VEF("@D
M,2!E<2`G3R<I('L*)&]U="`]("0R.PI]"F5L<VEF("@D,2!E<2`G8B<I('L*
M)&)U;F1L92`]("=S:71E)SL*?0IE;'-I9B`H)#$@97$@)T(G*2!["B1B=6YD
M;&4@/2`G86QL)SL*?0IE;'-I9B`H)#$@97$@)W$G*2!["B1Q=6EE="`](#$[
M"GT*96QS:68@*"0Q(&5Q("=,)RD@>PIO<&5N("1L;V=F:"P@(CX^(BP@)#(@
M;W(@9&EE('%Q6T-A;B=T(&]P96X@;&]G(&9I;&4@(B0R(CH@)"%=.PI]"F5L
M<VEF("@D,2!E<2`G5"<I('L*)&-A8VAE7VYA;64@/2`D,CL*?0IS:&EF="A`
M05)'5BD["FEF("AM>2`D8VUD(#T@)&1I<W1?8VUD>R0Q?2D@>PID96QE=&4@
M)$5.5GLG4$%27U1%35`G?3L*:6YI=%]I;F,H*3L*<F5Q=6ER92!005(Z.D1I
M<W0["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"D@=6YL97-S($!!4D=6.PHF>R)0
M05(Z.D1I<W0Z.B1C;60B?2@D7RD@9F]R($!!4D=6.PIE>&ET.PI]"GT*=6YS
M:&EF="!`24Y#+"!`861D7W1O7VEN8SL*?0I]"FEF("@D;W5T*2!["GL*<F5Q
M=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E<75I<F4@
M1&EG97-T.CI32$$["GT*;7D@)'!A<B`]('-H:69T*$!!4D=6*3L*;7D@)'II
M<#L*:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(&UY("1F:"P@)SPZ<F%W)RP@
M)'!A<B!O<B!D:64@<7%;0V%N)W0@9FEN9"!P87(@9FEL92`B)'!A<B(Z("0A
M73L*8FQE<W,H)&9H+"`G24\Z.D9I;&4G*3L*)'II<"`]($%R8VAI=F4Z.EII
M<"T^;F5W.PHH("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P87(I
M(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2`I"F]R(&1I92!Q<5M%<G)O<B!R
M96%D:6YG('II<"!A<F-H:79E("(D<&%R(ET["GT*;7D@)6UE=&%?<&%R(#T@
M9&\@>PII9B`H)'II<"!A;F0@;7D@)&UE=&$@/2`D>FEP+3YC;VYT96YT<R@G
M345402YY;6PG*2D@>PHD;65T82`]?B!S+RXJ7G!A<CHD+R]M<SL*)&UE=&$@
M/7X@<R]>7%,N*B\O;7,["B1M971A(#U^("]>("`H6UXZ72LI.B`H+BLI)"]M
M9SL*?0I].PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@;7D@)'!H+"`G/#IR
M87<G+"`D<&%R(&]R(&1I92!Q<5M#86XG="!R96%D('!A<B!F:6QE("(D<&%R
M(CH@)"%=.PIM>2`D8G5F.PIR96%D("1P:"P@)&)U9BP@-#L*9&EE('%Q6R(D
M<&%R(B!I<R!N;W0@82!P87(@9FEL95T@=6YL97-S("1B=68@97$@)%!+6DE0
M7TU!1TE#.PIC;&]S92`D<&@["GT*0W)E871E4&%T:"@D;W5T*2`["FUY("1F
M:"`]($E/.CI&:6QE+3YN97<H"B1O=70L"DE/.CI&:6QE.CI/7T-214%4*"D@
M?"!)3SHZ1FEL93HZ3U]21%=2*"D@?"!)3SHZ1FEL93HZ3U]44E5.0R@I+`HP
M-S<W+`HI(&]R(&1I92!Q<5M#86XG="!C<F5A=&4@9FEL92`B)&]U="(Z("0A
M73L*)&9H+3YB:6YM;V1E*"D["G-E96L@7T9(+"`P+"`P.PIM>2`D;&]A9&5R
M.PII9B`H9&5F:6YE9"`D<W1A<G1?;V9?1DE,15]S96-T:6]N*2!["G)E860@
M7T9(+"`D;&]A9&5R+"`D<W1A<G1?;V9?1DE,15]S96-T:6]N.PI](&5L<V4@
M>PIL;V-A;"`D+R`]('5N9&5F.PHD;&]A9&5R(#T@/%]&2#X["GT*:68@*"$D
M14Y6>U!!4E]615)"051)37T@86YD("1L;V%D97(@/7X@+UXH/SHC(7Q<0')E
M;2DO*2!["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PI005(Z.D9I
M;'1E<CHZ4&]D4W1R:7`M/F%P<&QY*%PD;&]A9&5R+"`D,"D["GT*)&9H+3YP
M<FEN="@D;&]A9&5R*0IO<B!D:64@<7%;17)R;W(@=W)I=&EN9R!L;V%D97(@
M=&\@(B1O=70B.B`D(5T["FEF("@D8G5N9&QE*2!["G)E<75I<F4@4$%2.CI(
M96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PII;FET7VEN
M8R@I.PIR97%U:7)E7VUO9'5L97,H*3L*;7D@0&EN8R`](&=R97`@>R`A+T)3
M1%!!3B\@?0IG<F5P('L**"1B=6YD;&4@;F4@)W-I=&4G*2!O<@HH)%\@;F4@
M)$-O;F9I9SHZ0V]N9FEG>V%R8VAL:6)E>'!](&%N9`HD7R!N92`D0V]N9FEG
M.CI#;VYF:6=[<')I=FQI8F5X<'TI.PI]($!)3D,["G-\+RM\+WQG+"!S?"\D
M?'P@9F]R96%C:"!`:6YC.PIM>2`E9FEL97,["B1F:6QE<WLD7WTK*R!F;W(@
M0$1Y;F%,;V%D97(Z.F1L7W-H87)E9%]O8FIE8W1S+"!V86QU97,@)4E.0SL*
M;7D@)&QI8E]E>'0@/2`D0V]N9FEG.CI#;VYF:6=[;&EB7V5X='T[("`@("`@
M("`@(R!86%@@;&EB7V5X="!V<R!D;&5X="`_"FUY("5W<FET=&5N.PIF;W)E
M86-H(&UY("1K97D@*'-O<G0@:V5Y<R`E9FEL97,I('L*;7D@*"1F:6QE+"`D
M;F%M92D["FEF("AD969I;F5D*&UY("1F8R`]("1005(Z.DAE879Y.CI&=6QL
M0V%C:&5[)&ME>7TI*2!["B@D9FEL92P@)&YA;64I(#T@*"1K97DL("1F8RD[
M"GT*96QS92!["F9O<F5A8V@@;7D@)&1I<B`H0&EN8RD@>PII9B`H)&ME>2`]
M?B!M?%Y<421D:7)<12\H+BHI)'QI*2!["B@D9FEL92P@)&YA;64I(#T@*"1K
M97DL("0Q*3L*;&%S=#L*?0II9B`H)&ME>2`]?B!M?%XO;&]A9&5R+UM>+UTK
M+R@N*BDD?"D@>PII9B`H;7D@)')E9B`]("1-;V1U;&5#86-H97LD,7TI('L*
M*"1F:6QE+"`D;F%M92D@/2`H)')E9BP@)#$I.PIL87-T.PI]"FEF("@M9B`B
M)&1I<B\D,2(I('L**"1F:6QE+"`D;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D[
M"FQA<W0["GT*?0I]"GT*;F5X="!U;FQE<W,@9&5F:6YE9"`D;F%M93L*;F5X
M="!I9B`D=W)I='1E;GLD;F%M97TK*SL*;F5X="!I9B`A<F5F*"1F:6QE*2!A
M;F0@)&9I;&4@/7X@+UPN7%$D;&EB7V5X=%Q%)"]I.PIO=71S*'-P<FEN=&8H
M<7%;4&%C:VEN9R!&24Q%("(E<R(N+BY=+"!R968@)&9I;&4@/R`D9FEL92T^
M>VYA;65](#H@)&9I;&4I*3L*;7D@)&-O;G1E;G0["FEF("AR968H)&9I;&4I
M*2!["B1C;VYT96YT(#T@)&9I;&4M/GMB=69].PI]"F5L<V4@>PIL;V-A;"`D
M+R`]('5N9&5F.PIO<&5N(&UY("1T:"P@)SPZ<F%W)RP@)&9I;&4@;W(@9&EE
M('%Q6T-A;B=T(')E860@(B1F:6QE(CH@)"%=.PHD8V]N=&5N="`](#PD=&@^
M.PIC;&]S92`D=&@["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^87!P;'DH7"1C
M;VYT96YT+"`B/&5M8F5D9&5D/B\D;F%M92(I"FEF("$D14Y6>U!!4E]615)"
M051)37T@86YD("1N86UE(#U^("]<+B@_.G!M?&EX?&%L*20O:3L*4$%2.CI&
M:6QT97(Z.E!A=&-H0V]N=&5N="T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F
M:6QE+"`D;F%M92D["GT*)&9H+3YP<FEN="@B1DE,12(L"G!A8VLH)TXG+"!L
M96YG=&@H)&YA;64I("L@.2DL"G-P<FEN=&8H(B4P.'@O)7,B+"!!<F-H:79E
M.CI::7`Z.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N86UE*2P*<&%C:R@G
M3B<L(&QE;F=T:"@D8V]N=&5N="DI+`HD8V]N=&5N="D*;W(@9&EE('%Q6T5R
M<F]R('=R:71I;F<@96UB961D960@1DE,12!T;R`B)&]U="(Z("0A73L*;W5T
M<RAQ<5M7<FET=&5N(&%S("(D;F%M92)=*3L*?0I]"FEF("@D>FEP*2!["B1Z
M:7`M/G=R:71E5&]&:6QE2&%N9&QE*"1F:"D@/3T@07)C:&EV93HZ6FEP.CI!
M6E]/2PIO<B!D:64@<7%;17)R;W(@=W)I=&EN9R!Z:7`@<&%R="!O9B`B)&]U
M=")=.PI]"FEF("@D;65T85]P87)[8VQE86Y]*2!["B1F:"T^<')I;G0H(EPP
M0TQ%04XB*3L*?0IE;'-E('L*:68@*"%D969I;F5D("1C86-H95]N86UE*2![
M"FUY("1C='@@/2!$:6=E<W0Z.E-(02T^;F5W*#$I.PIS965K("1F:"P@,"P@
M,#L*)&-T>"T^861D9FEL92@D9F@I.PIS965K("1F:"P@,"P@,CL*)&-A8VAE
M7VYA;64@/2`D8W1X+3YH97AD:6=E<W0["GT*)&-A8VAE7VYA;64@/2!S=6)S
M='(@)&-A8VAE7VYA;64L(#`L("1C86-H95]N86UE7W-I>F4["B1C86-H95]N
M86UE("X](")<,"(@>"`H)&-A8VAE7VYA;65?<VEZ92`M(&QE;F=T:"`D8V%C
M:&5?;F%M92D["B1F:"T^<')I;G0H)&-A8VAE7VYA;64L"B)<,$-!0TA%(BD[
M"GT*;7D@)&]F9G-E="`]("1F:"T^=&5L;"`M(&QE;F=T:"@D;&]A9&5R*3L*
M)&9H+3YP<FEN="AP86-K*"=.)RP@)&]F9G-E="DL"B1005)?34%'24,I.PHD
M9F@M/F-L;W-E(&]R(&1I92!Q<5M%<G)O<B!W<FET:6YG('1R86EL97(@;V8@
M(B1O=70B.B`D(5T["F-H;6]D(#`W-34L("1O=70["F5X:70["GT*>PIL87-T
M('5N;&5S<R!D969I;F5D("1S=&%R=%]P;W,["E]F:7A?<')O9VYA;64H*3L*
M<F5Q=6ER92!005(["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*
M>PIR97%U:7)E($9I;&4Z.D9I;F0["G)E<75I<F4@07)C:&EV93HZ6FEP.PI]
M"FUY("1F:"`]($E/.CI&:6QE+3YN97<[("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`C($%R8VAI=F4Z.EII<"!O<&5R871E<R!O;B!A;B!)3SHZ2&%N
M9&QE"B1F:"T^9F1O<&5N*&9I;&5N;RA?1D@I+"`G<B<I(&]R(&1I92!Q<5MF
M9&]P96XH*2!F86EL960Z("0A73L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I
M>F4H+7,@7T9(*3L*;7D@)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH)'II
M<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!R;V=N86UE*2`]/2!!<F-H
M:79E.CI::7`Z.D%:7T]+*"DI"F]R(&1I92!Q<5M%<G)O<B!R96%D:6YG('II
M<"!A<F-H:79E("(D<')O9VYA;64B73L*07)C:&EV93HZ6FEP.CIS971#:'5N
M:U-I>F4H-C0@*B`Q,#(T*3L*<'5S:"!`4$%2.CI,:6)#86-H92P@)'II<#L*
M)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2`]("1Z:7`["F]U=',H(D5X=')A
M8W1I;F<@>FEP+BXN(BD["FEF("AD969I;F5D("1%3E9[4$%27U1%35!]*2![
M(",@<VAO=6QD(&)E('-E="!A="!T:&ES('!O:6YT(0IF;W)E86-H(&UY("1M
M96UB97(@*"`D>FEP+3YM96UB97)S("D@>PIN97AT(&EF("1M96UB97(M/FES
M1&ER96-T;W)Y.PIM>2`D;65M8F5R7VYA;64@/2`D;65M8F5R+3YF:6QE3F%M
M93L*;F5X="!U;FQE<W,@)&UE;6)E<E]N86UE(#U^(&U["EX*+S]S:&QI8B\*
M*#\Z)$-O;F9I9SHZ0V]N9FEG>V%R8VAN86UE?2\I/PHH6UXO72LI"B0*?7@[
M"FUY("1E>'1R86-T7VYA;64@/2`D,3L*;7D@)&1E<W1?;F%M92`]($9I;&4Z
M.E-P96,M/F-A=&9I;&4H)$5.5GM005)?5$5-4'TL("1E>'1R86-T7VYA;64I
M.PII9B`H+68@)&1E<W1?;F%M92`F)B`M<R!?(#T]("1M96UB97(M/G5N8V]M
M<')E<W-E9%-I>F4H*2D@>PIO=71S*'%Q6U-K:7!P:6YG("(D;65M8F5R7VYA
M;64B('-I;F-E(&ET(&%L<F5A9'D@97AI<W1S(&%T("(D9&5S=%]N86UE(ETI
M.PI](&5L<V4@>PIO=71S*'%Q6T5X=')A8W1I;F<@(B1M96UB97)?;F%M92(@
M=&\@(B1D97-T7VYA;64B+BXN72D["B@D;65M8F5R+3YE>'1R86-T5&]&:6QE
M3F%M960H)&1E<W1?;F%M92D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I*0IO
M<B!D:64@<7%;17)R;W(@97AT<F%C=&EN9R!Z:7`@;65M8F5R('1O("(D9&5S
M=%]N86UE(ET["F-H;6]D*#`U-34L("1D97-T7VYA;64I(&EF("1>3R!E<2`B
M:'!U>"(["GT*?0I]"GT*=6YL97-S("@D4$%2.CI,:6)#86-H97LD<')O9VYA
M;65]*2!["F1I92`\/"`B+B(@=6YL97-S($!!4D=6.PI5<V%G93H@)#`@6R`M
M06QI8BYP87(@72!;("U)9&ER(%T@6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=
M(%L@<')O9W)A;2YP;"!="B0P(%L@+4)\+6(@72!;+4]O=71F:6QE72!S<F,N
M<&%R"BX*)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE(#T@)#`@/2!S
M:&EF="A`05)'5BD["GT*<W5B($-R96%T95!A=&@@>PIM>2`H)&YA;64I(#T@
M0%\["G)E<75I<F4@1FEL93HZ0F%S96YA;64["FUY("@D8F%S96YA;64L("1P
M871H+"`D97AT*2`]($9I;&4Z.D)A<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L
M("@G7"XN*B<I*3L*<F5Q=6ER92!&:6QE.CI0871H.PI&:6QE.CI0871H.CIM
M:W!A=&@H)'!A=&@I('5N;&5S<R@M92`D<&%T:"D[(",@;6MP871H(&1I97,@
M=VET:"!E<G)O<@I]"G-U8B!R97%U:7)E7VUO9'5L97,@>PIR97%U:7)E(&QI
M8CL*<F5Q=6ER92!$>6YA3&]A9&5R.PIR97%U:7)E(&EN=&5G97(["G)E<75I
M<F4@<W1R:6-T.PIR97%U:7)E('=A<FYI;F=S.PIR97%U:7)E('9A<G,["G)E
M<75I<F4@0V%R<#L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%<G)N
M;SL*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["G)E<75I<F4@17AP;W)T97([
M"G)E<75I<F4@1F-N=&P["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&
M:6QE.CI3<&5C.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E($-O;F9I9SL*
M<F5Q=6ER92!)3SHZ2&%N9&QE.PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E
M($-O;7!R97-S.CI:;&EB.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER
M92!$:6=E<W0Z.E-(03L*<F5Q=6ER92!005(["G)E<75I<F4@4$%2.CI(96%V
M>3L*<F5Q=6ER92!005(Z.D1I<W0["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O
M9%-T<FEP.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0["G)E
M<75I<F4@871T<FEB=71E<SL*979A;"![(')E<75I<F4@0W=D('T["F5V86P@
M>R!R97%U:7)E(%=I;C,R('T["F5V86P@>R!R97%U:7)E(%-C86QA<CHZ571I
M;"!].PIE=F%L('L@<F5Q=6ER92!!<F-H:79E.CI5;GII<#HZ0G5R<W0@?3L*
M979A;"![(')E<75I<F4@5&EE.CI(87-H.CI.86UE9$-A<'1U<F4@?3L*979A
M;"![(')E<75I<F4@4&5R;$E/.R!R97%U:7)E(%!E<FQ)3SHZ<V-A;&%R('T[
M"F5V86P@>R!R97%U:7)E('5T9C@@?3L*?0IS=6(@7W-E=%]P87)?=&5M<"![
M"FEF("AD969I;F5D("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0
M?2`]?B`O*"XK*2\I('L*)'!A<E]T96UP(#T@)#$["G)E='5R;CL*?0IF;W)E
M86-H(&UY("1P871H("@**&UA<"`D14Y6>R1??2P@<7<H(%!!4E]435!$25(@
M5$U01$E2(%1%35!$25(@5$5-4"!435`@*2DL"G%W*"!#.EQ<5$5-4"`O=&UP
M("X@*0HI('L*;F5X="!U;FQE<W,@9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A
M=&@@86YD("UW("1P871H.PIM>2`D=7-E<FYA;64["FUY("1P=W5I9#L*979A
M;"![*"1P=W5I9"D@/2!G971P=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM].PII
M9B`H(&1E9FEN960H)E=I;C,R.CI,;V=I;DYA;64I("D@>PHD=7-E<FYA;64@
M/2`F5VEN,S(Z.DQO9VEN3F%M93L*?0IE;'-I9B`H9&5F:6YE9"`D<'=U:60I
M('L*)'5S97)N86UE(#T@)'!W=6ED.PI]"F5L<V4@>PHD=7-E<FYA;64@/2`D
M14Y6>U5315).04U%?2!\?"`D14Y6>U5315)]('Q\("=365-414TG.PI]"FUY
M("1S=&UP9&ER(#T@(B1P871H)'-Y<WM?9&5L:6U]<&%R+2(N=6YP86-K*")(
M*B(L("1U<V5R;F%M92D["FUK9&ER("1S=&UP9&ER+"`P-S4U.PIM>2`D8V%C
M:&5?9&ER.PII9B`H)$5.5GM005)?0TQ%04Y]*2!["B1C86-H95]D:7(@/2`B
M=&5M<"TD)"(["GT*96QS92!["F]P96X@;7D@)&9H+"`B/#IR87<B+"`D<')O
M9VYA;64@;W(@9&EE('%Q6T-A;B=T(')E860@(B1P<F]G;F%M92(Z("0A73L*
M:68@*"AM>2`D;6%G:6-?<&]S(#T@9FEN9%]P87)?;6%G:6,H)&9H*2D@/CT@
M,"D@>PIS965K("1F:"P@)&UA9VEC7W!O<PHM("1&24Q%7V]F9G-E=%]S:7IE
M"BT@;&5N9W1H*")<,$-!0TA%(BDL(#`["FUY("1B=68["G)E860@)&9H+"`D
M8G5F+"!L96YG=&@H(EPP0T%#2$4B*3L*:68@*"1B=68@97$@(EPP0T%#2$4B
M*2!["G-E96L@)&9H+"`D;6%G:6-?<&]S"BT@)$9)3$5?;V9F<V5T7W-I>F4*
M+2!L96YG=&@H(EPP0T%#2$4B*0HM("1C86-H95]N86UE7W-I>F4L(#`["G)E
M860@)&9H+"`D8G5F+"`D8V%C:&5?;F%M95]S:7IE.PHD8G5F(#U^(',O7#`O
M+V<["B1C86-H95]D:7(@/2`B8V%C:&4M)&)U9B(["GT*?0IC;&]S92`D9F@[
M"GT*:68@*"$D8V%C:&5?9&ER*2!["B1C86-H95]D:7(@/2`B=&5M<"TD)"([
M"B1%3E9[4$%27T-,14%.?2`](#$["GT*)'-T;7!D:7(@+CT@(B1S>7-[7V1E
M;&EM?21C86-H95]D:7(B.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*)$5.5GM0
M05)?5$5-4'T@/2`D<W1M<&1I<CL*;&%S=#L*?0HD<&%R7W1E;7`@/2`D,2!I
M9B`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO
M.PI]"G-U8B!?<V%V95]A<R!["FUY("@D;F%M92P@)&-O;G1E;G1S+"`D;6]D
M92D@/2!`7SL*;7D@)&9U;&QN86UE(#T@(B1P87)?=&5M<"\D;F%M92(["G5N
M;&5S<R`H+64@)&9U;&QN86UE*2!["FUY("1T96UP;F%M92`]("(D9G5L;&YA
M;64N)"0B.PIM>2`D9F@["BAO<&5N("1F:"P@)SXZ<F%W)RP@)'1E;7!N86UE
M*0HF)B`H<')I;G0@)&9H("1C;VYT96YT<RD*)B8@*&-L;W-E("1F:"D*;W(@
M9&EE('%Q6T5R<F]R('=R:71I;F<@(B1T96UP;F%M92(Z("0A73L*8VAM;V0@
M)&UO9&4L("1T96UP;F%M92!I9B!D969I;F5D("1M;V1E.PIR96YA;64H)'1E
M;7!N86UE+"`D9G5L;&YA;64I(&]R('5N;&EN:R@D=&5M<&YA;64I.PI]"G)E
M='5R;B`D9G5L;&YA;64["GT*<W5B(%]S971?<')O9VYA;64@>PII9B`H9&5F
M:6YE9"`D14Y6>U!!4E]04D]'3D%-17T@86YD("1%3E9[4$%27U!23T=.04U%
M?2`]?B`O*"XK*2\I('L*)'!R;V=N86UE(#T@)#$["GT*)'!R;V=N86UE('Q\
M/2`D,#L*:68@*"1%3E9[4$%27U1%35!](&%N9"!I;F1E>"@D<')O9VYA;64L
M("1%3E9[4$%27U1%35!]*2`^/2`P*2!["B1P<F]G;F%M92`]('-U8G-T<B@D
M<')O9VYA;64L(')I;F1E>"@D<')O9VYA;64L("1S>7-[7V1E;&EM?2D@*R`Q
M*3L*?0II9B`H(21%3E9[4$%27U!23T=.04U%?2!O<B!I;F1E>"@D<')O9VYA
M;64L("1S>7-[7V1E;&EM?2D@/CT@,"D@>PII9B`H;W!E;B!M>2`D9F@L("<\
M)RP@)'!R;V=N86UE*2!["G)E='5R;B!I9B`M<R`D9F@["GT*:68@*"US("(D
M<')O9VYA;64D<WES>U]E>&5](BD@>PHD<')O9VYA;64@+CT@)'-Y<WM?97AE
M?3L*<F5T=7)N.PI]"GT*9F]R96%C:"!M>2`D9&ER("AS<&QI="`O7%$D<WES
M>W!A=&A?<V5P?5Q%+RP@)$5.5GM0051(?2D@>PIN97AT(&EF(&5X:7-T<R`D
M14Y6>U!!4E]414U0?2!A;F0@)&1I<B!E<2`D14Y6>U!!4E]414U0?3L*)&1I
M<B`]?B!S+UQ1)'-Y<WM?9&5L:6U]7$4D+R\["B@H)'!R;V=N86UE(#T@(B1D
M:7(D<WES>U]D96QI;7TD<')O9VYA;64D<WES>U]E>&5](BDL(&QA<W0I"FEF
M("US("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE)'-Y<WM?97AE?2(["B@H
M)'!R;V=N86UE(#T@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64B*2P@;&%S
M="D*:68@+7,@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64B.PI]"GT*<W5B
M(%]F:7A?<')O9VYA;64@>PHD,"`]("1P<F]G;F%M92!\?#T@)$5.5GM005)?
M4%)/1TY!345].PII9B`H:6YD97@H)'!R;V=N86UE+"`D<WES>U]D96QI;7TI
M(#P@,"D@>PHD<')O9VYA;64@/2`B+B1S>7-[7V1E;&EM?21P<F]G;F%M92([
M"GT*;7D@)'!W9"`]("AD969I;F5D("9#=V0Z.F=E=&-W9"D@/R!#=V0Z.F=E
M=&-W9"@I"CH@*"AD969I;F5D("97:6XS,CHZ1V5T0W=D*2`_(%=I;C,R.CI'
M971#=V0H*2`Z(&!P=V1@*3L*8VAO;7`H)'!W9"D["B1P<F]G;F%M92`]?B!S
M+UXH/SU<+EPN/UQ1)'-Y<WM?9&5L:6U]7$4I+R1P=V0D<WES>U]D96QI;7TO
M.PHD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64["GT*<W5B(%]P87)?
M:6YI=%]E;G8@>PII9B`H("1%3E9[4$%27TE.251)04Q)6D5$?2LK(#T](#$@
M*2!["G)E='5R;CL*?2!E;'-E('L*)$5.5GM005)?24Y)5$E!3$E:141](#T@
M,CL*?0IF;W(@*'%W*"!34$%73D5$(%1%35`@0TQ%04X@1$5"54<@0T%#2$4@
M4%)/1TY!344@*2`I('L*9&5L971E("1%3E9[(E!!4E\D7R)].PI]"F9O<B`H
M<7<O(%1-4$1)4B!414U0($-,14%.($1%0E5'("\I('L*)$5.5GLB4$%27R1?
M(GT@/2`D14Y6>R)005)?1TQ/0D%,7R1?(GT@:68@97AI<W1S("1%3E9[(E!!
M4E]'3$]"04Q?)%\B?3L*?0II9B`H)$5.5GM005)?5$5-4'TI('L*9&5L971E
M("1%3E9[4$%27T-,14%.?3L*?0I]"G-U8B!O=71S('L*<F5T=7)N(&EF("1Q
M=6EE=#L*:68@*"1L;V=F:"D@>PIP<FEN="`D;&]G9F@@(D!?7&XB.PI]"F5L
M<V4@>PIP<FEN="`B0%]<;B(["GT*?0IS=6(@:6YI=%]I;F,@>PIR97%U:7)E
M($-O;F9I9SL*<'5S:"!`24Y#+"!G<F5P(&1E9FEN960L(&UA<"`D0V]N9FEG
M.CI#;VYF:6=[)%]]+"!Q=R@*87)C:&QI8F5X<"!P<FEV;&EB97AP('-I=&5A
M<F-H97AP('-I=&5L:6)E>'`*=F5N9&]R87)C:&5X<"!V96YD;W)L:6)E>'`*
M*3L*?0IP86-K86=E(&UA:6X["G)E<75I<F4@4$%2.PIU;G-H:69T($!)3D,L
M(%PF4$%2.CIF:6YD7W!A<CL*4$%2+3YI;7!O<G0H0'!A<E]A<F=S*3L*9&EE
M('%Q6W!A<BYP;#H@0V%N)W0@;W!E;B!P97)L('-C<FEP="`B)'!R;V=N86UE
M(CH@3F\@<W5C:"!F:6QE(&]R(&1I<F5C=&]R>5QN70IU;FQE<W,@+64@)'!R
M;V=N86UE.PID;R`D<')O9VYA;64["D-/4D4Z.F5X:70H)#$I(&EF("@D0"`]
M?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D0"!I9B`D0#L*?3L*)#HZ
M7U]%4E)/4B`]("1`(&EF("1`.PI]"D-/4D4Z.F5X:70H)#$I(&EF("@D.CI?
M7T524D]2(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("0Z.E]?15)2
M3U(@:68@)#HZ7U]%4E)/4CL*,3L*7U]%3D1?7PH`<&5R;'AS:2YC`````$H!
M`!1'`0``````U$<!`-A'`0#T20$`'$<!`/Q)`0``````X$D!`.A)`0``````
M`$-!0TA%```^````00````P```!!````$0```$$````G````00```#8```!!
M`````P```$$````&````00```!4```!!````#P```$$````.````00```"8`
M``!!````$P```$$````I````00````(```!!````&0```$$````*````00``
M``L```!!``````````````!XD/]_`0``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````N!D!`)`9`0``````````
M```````````````````````!````%`,```$````D`P```0```"X#```,````
ME!,!``T````<1@$`&0```,R=`0`;````!````!H```#0G0$`'`````0```#U
M_O]OM`$!``4```"L"P$`!@```$P%`0`*````J00```L````0````%0``````
M```#````])X!``(```#H`0``%````!$````7````K!$!`!$```!T$0$`$@``
M`#@````3````"````!X````(````^___;P$```#^__]O)!$!`/___V\"````
M\/__;U80`0``````````````````````````````````````````````````
M``````````````#LG0$```````````"@$P$`H!,!`*`3`0"@$P$`H!,!`*`3
M`0"@$P$`H!,!`*`3`0"@$P$`H!,!`*`3`0"@$P$`H!,!`*`3`0"@$P$`H!,!
M`*`3`0"@$P$`H!,!`*`3`0"@$P$`H!,!`*`3`0"@$P$`H!,!`*`3`0"@$P$`
MH!,!`*`3`0"@$P$`H!,!`*`3`0"@$P$`H!,!`*`3`0"@$P$`H!,!`*`3`0"@
M$P$`H!,!`*`3`0"@$P$`H!,!`*`3`0"@$P$`H!,!`*`3`0"@$P$`H!,!`*`3
M`0"@$P$`H!,!`*`3`0"@$P$`H!,!`*`3`0"@$P$`H!,!`*`3`0"@$P$`````
M``````"0%@$````````````*4$%2+G!M"@`````(2@$`1T-#.B`H4F%S<&)I
M86X@,3,N,BXP+3$V+C$K<G!I,2D@,3,N,BXP`$$N````865A8FD``20````%
M-@`&!@@!"0$*`A($$P$4`14!%P,8`1D!&@(<`2(!`"YS:'-T<G1A8@`N:6YT
M97)P`"YN;W1E+F=N=2YB=6EL9"UI9``N;F]T92Y!0DDM=&%G`"YG;G4N:&%S
M:``N9'EN<WEM`"YD>6YS='(`+F=N=2YV97)S:6]N`"YG;G4N=F5R<VEO;E]R
M`"YR96PN9'EN`"YR96PN<&QT`"YI;FET`"YT97AT`"YF:6YI`"YR;V1A=&$`
M+D%232YE>&ED>``N96A?9G)A;64`+FEN:71?87)R87D`+F9I;FE?87)R87D`
M+F1A=&$N<F5L+G)O`"YD>6YA;6EC`"YG;W0`+F1A=&$`+F)S<P`N8V]M;65N
M=``N05)-+F%T=')I8G5T97,`````````````````````````````````````
M``````````````````````L````!`````@```%0!`0!4`0``&0``````````
M`````0`````````3````!P````(```!P`0$`<`$``"0```````````````0`
M````````)@````<````"````E`$!`)0!```@```````````````$````````
M`#0```#V__]O`@```+0!`0"T`0``F`,```4`````````!`````0````^````
M"P````(```!,!0$`3`4``&`&```&`````0````0````0````1@````,````"
M````K`L!`*P+``"I!``````````````!`````````$X```#___]O`@```%80
M`0!6$```S`````4``````````@````(```!;````_O__;P(````D$0$`)!$`
M`%`````&`````@````0`````````:@````D````"````=!$!`'01```X````
M!0`````````$````"````',````)````0@```*P1`0"L$0``Z`$```4````6
M````!`````@```!\`````0````8```"4$P$`E!,```P```````````````0`
M````````=P````$````&````H!,!`*`3``#P`@`````````````$````!```
M`((````!````!@```)`6`0"0%@``C"\`````````````$`````````"(````
M`0````8````<1@$`'$8```@```````````````0`````````C@````$````"
M````)$8!`"1&```H0@`````````````$`````````)8````!``!P@@```$R(
M`0!,B```"`````T`````````!`````````"A`````0````(```!4B`$`5(@`
M``0```````````````0`````````JP````X````#````S)T!`,R-```$````
M```````````$````!````+<````/`````P```-"=`0#0C0``!```````````
M````!`````0```##`````0````,```#4G0$`U(T``!<```````````````0`
M````````T`````8````#````[)T!`.R-```(`0``!@`````````$````"```
M`-D````!`````P```/2>`0#TC@``#`$`````````````!`````0```#>````
M`0````,`````H`$``)```!@```````````````0`````````Y`````@````#
M````&*`!`!B0```H```````````````(`````````.D````!````,```````
M```8D```*````````````````0````$```#R`````P``<```````````0)``
M`"\```````````````$``````````0````,``````````````&^0```"`0``
0```````````!````````````
